/**
 * File customizer.js.
 *
 * Theme Customizer enhancements for a better user experience.
 *
 * Contains handlers to make Theme Customizer preview reload changes asynchronously.
 */
 ( function( $ ) {

	
 	const music_zone_pro_section_lists = ['slider_section', 'service_section', 'about_section', 'playlist_section', 'album_section', 'promotion_section', 'recent_product_section', 'events_section', 'gallery_section', 'team_section', 'counter_section', 'testimonial_section', 'latest_posts_section', 'subscription_section', 'partners_section', 'contact_section', 'featured_posts_section', 'recent_posts_section', 'popular_posts_section', 'instagram_section', 'popular_products_section', 'featured_products_section', 'trending_product_section'];
    music_zone_pro_section_lists.forEach( music_zone_pro_homepage_scroll_preview );

 	function music_zone_pro_homepage_scroll_preview(item, index) {
		// Collect information from customize-controls.js about which panels are opening.
		wp.customize.bind( 'preview-ready', function() {

		// Initially hide the theme option placeholders on load.
		$( '.panel-placeholder' ).hide();
		wp.customize.preview.bind( item, function( data ) {
		// Only on the front page.
		if ( ! $( 'body' ).hasClass( 'home' ) ) {
			return;
		}

		// When the section is expanded, show and scroll to the content placeholders, exposing the edit links.
		if ( true === data.expanded ) {
			$('html, body').animate({
				'scrollTop' : $('#music_zone_pro_'+item).position().top
			});
		} 
	});

	});
	}


	// Site title and description.
	wp.customize( 'blogname', function( value ) {
		value.bind( function( to ) {
			$( '.site-title a' ).text( to );
		} );
	} );
	wp.customize( 'blogdescription', function( value ) {
		value.bind( function( to ) {
			$( '.site-description' ).text( to );
		} );
	} );

	// Header text color.
	wp.customize( 'header_textcolor', function( value ) {
		value.bind( function( to ) {
			if ( 'blank' === to ) {
				$( '.site-title a, .site-description' ).css( {
					'clip': 'rect(1px, 1px, 1px, 1px)',
					'position': 'absolute'
				} );
			} else {
				$( '.site-title a, .site-description' ).css( {
					'clip': 'auto',
					'position': 'relative'
				} );
			}
		} );
	} );

	// Header title color.
	wp.customize( 'music_zone_pro_theme_options[header_title_color]', function( value ) {
		value.bind( function( to ) {
			if ( 'blank' === to ) {
				$( '.site-title a' ).css( {
					'clip': 'rect(1px, 1px, 1px, 1px)',
					'position': 'absolute'
				} );
			} else {
				$( '.site-title a' ).css( {
					'clip': 'auto',
					'position': 'relative'
				} );
				$( '.site-title a' ).css( {
					'color': to
				} );
			}
		} );
	} );

	// Header tagline color.
	wp.customize( 'music_zone_pro_theme_options[header_tagline_color]', function( value ) {
		value.bind( function( to ) {
			if ( 'blank' === to ) {
				$( '.site-description' ).css( {
					'clip': 'rect(1px, 1px, 1px, 1px)',
					'position': 'absolute'
				} );
			} else {
				$( '.site-description' ).css( {
					'clip': 'auto',
					'position': 'relative'
				} );
				$( '.site-description' ).css( {
					'color': to
				} );
			}
		} );
	} );

	// Color scheme.
	wp.customize( 'music_zone_pro_theme_options[colorscheme]', function( value ) {
		value.bind( function( to ) {

			// Update color body class.
			$( 'body' )
				.removeClass( 'colors-light colors-dark colors-custom' )
				.addClass( 'colors-' + to );
		});
	});

	// Custom color hue.
	wp.customize( 'music_zone_pro_theme_options[colorscheme_hue]', function( value ) {
		value.bind( function( to ) {

			// Update custom color CSS
			var style = $( '#custom-theme-colors' ),
			    color = style.data( 'color' ),
			    css = style.html();
			css = css.split( color ).join( to );
			style.html( css )
			     .data( 'color', to );
		} );
	} );

	wp.customize( 'music_zone_pro_theme_options[theme_version]', function( value ) {
	value.bind( function( to ) {
			if( to == 'dark-version' ){
				$('body').removeClass( 'lite-version' );
				$('body').addClass( 'dark-version' );
			}else{
				$('body').removeClass( 'dark-version' );
				$('body').addClass( 'lite-version' );
			}
			
		});
	});

		wp.customize( 'music_zone_pro_theme_options[blog_column]', function( value ) {
	value.bind( function( to ) {
			if( to == 'col-1' ){
				$('body').removeClass( 'col-2' );
				$('body').removeClass( 'col-3' );
				$('body').addClass( 'col-1' );
			}else if ( to == 'col-2'){
				$('body').removeClass( 'col-1' );
				$('body').removeClass( 'col-3' );
				$('body').addClass( 'col-2' );
			}else if ( to == 'col-3'){
				$('body').removeClass( 'col-1' );
				$('body').removeClass( 'col-2' );
				$('body').addClass( 'col-3' );
			}
			
		});
	})


		wp.customize( 'music_zone_pro_theme_options[hide_banner]', function( value ) {
			value.bind( function( to ) {
				if( to == 'true' ){
					$('.blog #page-site-header, .archive #page-site-header, .search #page-site-header').css( 'background-image', 'none' );
					$('.blog #page-site-header, .archive #page-site-header, .search #page-site-header').css( 'padding', '0px 0px' );
					$('.blog #page-site-header, .archive #page-site-header, .search #page-site-header').css( 'background-color', 'transparent' );
					$('.blog #page-site-header .header-wrapper, .archive #page-site-header .header-wrapper, .search #page-site-header .header-wrapper').css( 'background-color', '#333' );
					$('.blog #page-site-header .header-wrapper, .archive #page-site-header .header-wrapper, .search #page-site-header .header-wrapper').css( 'margin-top', '50px' );
					$('.blog #page-site-header .overlay, .archive #page-site-header .overlay, .search #page-site-header .overlay').css( 'display', 'none' );
					$('#masthead').css('background-color', '#000');
					$('body').addClass( 'relative-header' );
				}else {
					$('.blog #page-site-header, .archive #page-site-header, .search #page-site-header').css( 'background-image', 'url(' + header_image_url + ')' );
					$('.blog #page-site-header, .archive #page-site-header, .search #page-site-header').css( 'padding', '200px 0px' );
					$('.blog #page-site-header .header-wrapper, .archive #page-site-header .header-wrapper, .search #page-site-header .header-wrapper').css( 'background-color', 'transparent' );
					$('.blog #page-site-header .overlay, .archive #page-site-header .overlay, .search #page-site-header .overlay').css( 'display', 'block' );
					$('body').removeClass( 'relative-header' );
					$('#masthead').css('background-color', 'transparent');

				}

			});
		});



		wp.customize( 'music_zone_pro_theme_options[hide_image]', function( value ) {
			value.bind( function( to ) {
				if( to == 'true' ){

					$( '.archive .featured-image img, .blog .featured-image img, .search .featured-image img' ).css( 'display', 'none' );
				}else {
					$( '.archive .featured-image img, .blog .featured-image img, .search .featured-image img' ).css( 'display', 'block' );
				}
				
			});
		});



		wp.customize( 'music_zone_pro_theme_options[hide_content]', function( value ) {
			value.bind( function( to ) {
				if( to == 'true' ){
					$( '.archive article .entry-content, .blog article .entry-content, .search article .entry-content' ).css( 'display', 'none' );
				}else {
					$( '.archive article .entry-content, .blog article .entry-content, .search article .entry-content' ).css( 'display', 'block' );
				}
				
			});
		});

		//single posts

		wp.customize( 'music_zone_pro_theme_options[single_post_hide_banner]', function( value ) {
			value.bind( function( to ) {
				if( to == 'true' ){
					$('.single #page-site-header').css( 'background-image', 'none' );
					$('.single #page-site-header').css( 'padding', '0px 0px' );
					$('.single #page-site-header').css( 'background-color', 'transparent' );
					$('.single #page-site-header .header-wrapper').css( 'background-color', '#333' );
					$('.single #page-site-header .header-wrapper').css( 'margin-top', '50px' );
					$('.single #page-site-header .overlay').css( 'display', 'none' );
					$('#masthead').css('background-color', '#000');
					$('body').addClass( 'relative-header' );
				}else {
					$('.single #page-site-header').css( 'background-image', 'url(' + header_image_url + ')' );
					$('.single #page-site-header').css( 'padding', '200px 0px' );
					$('.single #page-site-header .header-wrapper').css( 'background-color', 'transparent' );
					$('.single #page-site-header .overlay').css( 'display', 'block' );
					$('body').removeClass( 'relative-header' );
					$('#masthead').css('background-color', 'transparent');

				}

			});
		});

		wp.customize( 'music_zone_pro_theme_options[single_post_hide_image]', function( value ) {
			value.bind( function( to ) {
				if( to == 'true' ){
					$( '.single .single-wrapper article img' ).css( 'display', 'none' );
				}else {
					$( '.single .single-wrapper article img' ).css( 'display', 'block' );
				}
				
			});
		});

		wp.customize( 'music_zone_pro_theme_options[single_post_hide_date]', function( value ) {
			value.bind( function( to ) {
				if( to == 'true' ){
					$( '.single .entry-meta .posted-on' ).css( 'display', 'none' );
				}else {
					$( '.single .entry-meta .posted-on' ).css( 'display', 'revert' );
				}
				
			});
		});

		wp.customize( 'music_zone_pro_theme_options[single_post_hide_author]', function( value ) {
			value.bind( function( to ) {
				if( to == 'true' ){
					$( '.single .byline' ).css( 'display', 'none' );
				}else {
					$( '.single .byline' ).css( 'display', 'revert' );
				}
				
			});
		});

		wp.customize( 'music_zone_pro_theme_options[single_post_hide_category]', function( value ) {
			value.bind( function( to ) {
				if( to == 'true' ){
					$( '.single .cat-links' ).css( 'display', 'none' );
				}else {
					$( '.single .cat-links' ).css( 'display', 'revert' );
				}
				
			});
		});

		wp.customize( 'music_zone_pro_theme_options[single_post_hide_tags]', function( value ) {
			value.bind( function( to ) {
				if( to == 'true' ){
					$( '.single .byline' ).css( 'display', 'none' );
				}else {
					$( '.single .byline' ).css( 'display', 'revert' );
				}
				
			});
		});
} )( jQuery );
