<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage  Music Zone Pro
 * @since  Music Zone Pro 1.0.0
 */

if ( ! function_exists( 'music_zone_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since  Music Zone Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function music_zone_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'music_zone_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'music_zone_pro_is_static_homepage_enable' ) ) :
	/**
	 * Check if static homepage is enabled.
	 *
	 * @since Music Zone Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function music_zone_pro_is_static_homepage_enable( $control ) {
		return ( 'page' == $control->manager->get_setting( 'show_on_front' )->value() );
	}
endif;

if ( ! function_exists( 'music_zone_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since  Music Zone Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function music_zone_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'music_zone_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'music_zone_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since  Music Zone Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function music_zone_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'music_zone_pro_theme_options[pagination_enable]' )->value();
	}
endif;

/*==================Slider===============*/

/**
 * Check if slider section is enabled.
 *
 * @since  Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'music_zone_pro_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if service section is enabled.
 *
 * @since  Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'music_zone_pro_theme_options[service_section_enable]' )->value() );
}

/**
 * Check if service section content type is category.
 *
 * @since  Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_service_section_hr_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[service_content_type]' )->value();
	return music_zone_pro_is_service_section_enable( $control ) && ( 'category' != $content_type);
}


/**
 * Check if slider section content type is post.
 *
 * @since  Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[slider_content_type]' )->value();
	return music_zone_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if slider section content type is page.
 *
 * @since  Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[slider_content_type]' )->value();
	return music_zone_pro_is_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is category.
 *
 * @since  Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[slider_content_type]' )->value();
	return music_zone_pro_is_slider_section_enable( $control ) && ( 'category' == $content_type );
}
/**
 * Check if slider separator section is enabled.
 *
 * @since  Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_slider_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[slider_content_type]' )->value();
    return music_zone_pro_is_slider_section_enable( $control ) && !( 'category' == $content_type );
}

/*==================Service===============*/

/**
 * Check if service section content type is page.
 *
 * @since  Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[service_content_type]' )->value();
	return music_zone_pro_is_service_section_enable( $control ) && ( 'page' == $content_type );
}
/**
 * Check if service section content type is post.
 *
 * @since  Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[service_content_type]' )->value();
	return music_zone_pro_is_service_section_enable( $control ) && ( 'post' == $content_type );
}
/**
 * Check if service section content type is category.
 *
 * @since  Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[service_content_type]' )->value();
	return music_zone_pro_is_service_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if playlist section is enabled.
 *
 * @since  Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_playlist_section_enable( $control ) {
	return ( $control->manager->get_setting( 'music_zone_pro_theme_options[playlist_section_enable]' )->value() );
}


function music_zone_pro_is_music_player_section_enable( $control ) {
	return ( $control->manager->get_setting( 'music_zone_pro_theme_options[music_player_section_enable]' )->value() );
}


/*==================Album===============*/

/**
 * Check if album section is enabled.
 *
 * @since  Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_album_section_enable( $control ) {
	return ( $control->manager->get_setting( 'music_zone_pro_theme_options[album_section_enable]' )->value() );
}


/**
 * Check if recent album section content type is product.
 *
 * @since  Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_album_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[album_content_type]' )->value();
	return music_zone_pro_is_album_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if album section content type is category.
 *
 * @since  Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_album_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[album_content_type]' )->value();
	return music_zone_pro_is_album_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if album section content type is product category.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_album_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[album_content_type]' )->value();
	return music_zone_pro_is_album_section_enable( $control ) && ( 'product-category' == $content_type );
}

/**
 * Check if album section content type is page.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_album_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[album_content_type]' )->value();
	return music_zone_pro_is_album_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if album section content type is post.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_album_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[album_content_type]' )->value();
	return music_zone_pro_is_album_section_enable( $control ) && ( 'post' == $content_type );
}

/*==================Promotion===============*/

/**
 * Check if promotion section is enabled.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_promotion_section_enable( $control ) {
	return ( $control->manager->get_setting( 'music_zone_pro_theme_options[promotion_section_enable]' )->value() );
}

/**
 * Check if promotion section content type is page.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_promotion_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[promotion_content_type]' )->value();
	return music_zone_pro_is_promotion_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if promotion section content type is post.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_promotion_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[promotion_content_type]' )->value();
	return music_zone_pro_is_promotion_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if promotion section content type is category.
 *
 * @since  Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_promotion_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[promotion_content_type]' )->value();
	return music_zone_pro_is_promotion_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if promotion section content type is custom.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_promotion_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[promotion_content_type]' )->value();
	return music_zone_pro_is_promotion_section_enable( $control ) && ( 'custom' == $content_type );
}

/*==================Recent Product===============*/

/**
 * Check if product section is enabled.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_recent_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'music_zone_pro_theme_options[recent_product_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

/**
 * Check if product section content type is product.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_recent_product_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[recent_product_content_type]' )->value();
	return music_zone_pro_is_recent_product_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if product section content type is product category.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_recent_product_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[recent_product_content_type]' )->value();
	return music_zone_pro_is_recent_product_section_enable( $control ) && ( 'product-category' == $content_type );
}

/*==================Gallery===============*/

/**
 * Check if gallery section content type is category.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_gallery_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[gallery_content_type]' )->value();
	return music_zone_pro_is_gallery_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if gallery section content type is post.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_gallery_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[gallery_content_type]' )->value();
	return music_zone_pro_is_gallery_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if gallery section content type is page.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_gallery_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[gallery_content_type]' )->value();
	return music_zone_pro_is_gallery_section_enable( $control ) && ( 'page' == $content_type );
}


/**
 * Check if gallery section is enabled.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_gallery_section_enable( $control ) {
	return ( $control->manager->get_setting( 'music_zone_pro_theme_options[gallery_section_enable]' )->value() );
}

/**
 * Check if about section is enabled.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'music_zone_pro_theme_options[about_section_enable]' )->value() );
}

/*==================About===============*/

/**
 * Check if about section content type is post.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_about_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[about_content_type]' )->value();
	return music_zone_pro_is_about_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if about section content type is page.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_about_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[about_content_type]' )->value();
	return music_zone_pro_is_about_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if about section content type is custom.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_about_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[about_content_type]' )->value();
	return music_zone_pro_is_about_section_enable( $control ) && ( 'custom' == $content_type );
}

/*==================Team===============*/

/**
 * Check if team section is enabled.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_team_section_enable( $control ) {
	return ( $control->manager->get_setting( 'music_zone_pro_theme_options[team_section_enable]' )->value() );
}

/**
 * Check if team section content type is category.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_team_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[team_content_type]' )->value();
	return music_zone_pro_is_team_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if team section content type is page.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_team_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[team_content_type]' )->value();
	return music_zone_pro_is_team_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if team section content type is post.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_team_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[team_content_type]' )->value();
	return music_zone_pro_is_team_section_enable( $control ) && ( 'post' == $content_type );
}

/*==================Testimonial===============*/

/**
 * Check if testimonial section is enabled.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_testimonial_section_enable( $control ) {
	return ( $control->manager->get_setting( 'music_zone_pro_theme_options[testimonial_section_enable]' )->value() );
}

/**
 * Check if testimonial section seperator.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_testimonial_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[testimonial_content_type]' )->value();
	return music_zone_pro_is_testimonial_section_enable( $control ) && ( 'category' !== $content_type );
}

/**
 * Check if testimonial section content type is post.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_testimonial_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[testimonial_content_type]' )->value();
	return music_zone_pro_is_testimonial_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if testimonial section content type is page.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_testimonial_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[testimonial_content_type]' )->value();
	return music_zone_pro_is_testimonial_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if testimonial section content type is category.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_testimonial_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[testimonial_content_type]' )->value();
	return music_zone_pro_is_testimonial_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if testimonial section content type is position.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_testimonial_section_content_position_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[testimonial_content_type]' )->value();
	return music_zone_pro_is_testimonial_section_enable( $control ) && ( 'category' !== $content_type );
}

/**
 * Check if testimonial section content type is custom.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_testimonial_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[testimonial_content_type]' )->value();
	return music_zone_pro_is_testimonial_section_enable( $control ) && ( 'custom' == $content_type );
}

/*==================Latest Posts===============*/

/**
 * Check if latest posts section is enabled.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_latest_posts_section_enable( $control ) {
	return ( $control->manager->get_setting( 'music_zone_pro_theme_options[latest_posts_section_enable]' )->value() );
}

/**
 * Check if blog section content type is post.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_latest_posts_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[latest_posts_content_type]' )->value();
	return music_zone_pro_is_latest_posts_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog section content type is page.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_latest_posts_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[latest_posts_content_type]' )->value();
	return music_zone_pro_is_latest_posts_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section content type is category.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_latest_posts_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[latest_posts_content_type]' )->value();
	return music_zone_pro_is_latest_posts_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section content type is recent.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_latest_posts_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[latest_posts_content_type]' )->value();
	return music_zone_pro_is_latest_posts_section_enable( $control ) && ( 'recent' == $content_type );
}

/*==================Subscription===============*/

/**
 * Check if subscription section is enabled.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_subscription_section_enable( $control ) {
	return ( $control->manager->get_setting( 'music_zone_pro_theme_options[subscription_section_enable]' )->value() ) && class_exists( 'Jetpack' );
}

/*==================Event===============*/

/**
 * Check if event section is enabled.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_event_section_enable( $control ) {
	return ( $control->manager->get_setting( 'music_zone_pro_theme_options[event_section_enable]' )->value() );
}

/**
 * Check if event section content type is post.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_event_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[event_content_type]' )->value();
	return music_zone_pro_is_event_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if event section content type is page.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_event_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[event_content_type]' )->value();
	return music_zone_pro_is_event_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if event section content type is category.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_event_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[event_content_type]' )->value();
	return music_zone_pro_is_event_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if event section content type is event.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_event_section_content_event_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[event_content_type]' )->value();
	return music_zone_pro_is_event_section_enable( $control ) && ( 'event' == $content_type );
}

/**
 * Check if event section content type is event category.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_event_section_content_event_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[event_content_type]' )->value();
	return music_zone_pro_is_event_section_enable( $control ) && ( 'event-category' == $content_type );
}

/*==================Default layout===============*/
function music_zone_pro_is_default_layout( $control ) {
	$design = $control->manager->get_setting( 'music_zone_pro_theme_options[home_layout]' )->value();
	return ( 'default-design' == $design );
}


/*==================Second-Layout===============*/

function music_zone_pro_is_second_layout( $control ) {
	$design = $control->manager->get_setting( 'music_zone_pro_theme_options[home_layout]' )->value();
	return ( 'second-design' == $design );
}

/*==================Third-Layout===============*/


function music_zone_pro_is_third_layout( $control ) {
	$design = $control->manager->get_setting( 'music_zone_pro_theme_options[home_layout]' )->value();
	return ( 'third-design' == $design );
}


/*==================Fourth-Layout===============*/


function music_zone_pro_is_fourth_layout( $control ) {
	$design = $control->manager->get_setting( 'music_zone_pro_theme_options[home_layout]' )->value();
	return ( 'fourth-design' == $design );
}

/*==================Partners===============*/

/**
 * Check if partners section is enabled.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_partners_section_enable( $control ) {
	return ( $control->manager->get_setting( 'music_zone_pro_theme_options[partners_section_enable]' )->value() );
}

/*========================Contact===========================*/
/**
 * Check if contact section is enabled.
 *
 * @since  Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_contact_section_enable( $control ) {
	return ( $control->manager->get_setting( 'music_zone_pro_theme_options[contact_section_enable]' )->value() );
}

/*========================counter===========================*/
/**
 * Check if counter section is enabled.
 *
 * @since  Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_counter_section_enable( $control ) {
	return ( $control->manager->get_setting( 'music_zone_pro_theme_options[counter_section_enable]' )->value() );
}

/*==================Featured Posts===============*/

/**
 * Check if featured_posts section is enabled.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_featured_posts_section_enable( $control ) {
	return ( $control->manager->get_setting( 'music_zone_pro_theme_options[featured_posts_section_enable]' )->value() );
}

/**
 * Check if featured_posts section content type is page.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_featured_posts_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[featured_posts_content_type]' )->value();
	return music_zone_pro_is_featured_posts_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if featured_posts section content type is post.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_featured_posts_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[featured_posts_content_type]' )->value();
	return music_zone_pro_is_featured_posts_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if featured_posts section content type is category.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_featured_posts_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[featured_posts_content_type]' )->value();
	return music_zone_pro_is_featured_posts_section_enable( $control ) && ( 'category' == $content_type );
}

/*==================Recent Posts===============*/

/**
 * Check if recent_posts section is enabled.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_recent_posts_section_enable( $control ) {
	return ( $control->manager->get_setting( 'music_zone_pro_theme_options[recent_posts_section_enable]' )->value() );
}

/**
 * Check if recent_posts section content type is page.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_recent_posts_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[recent_posts_content_type]' )->value();
	return music_zone_pro_is_recent_posts_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if recent_posts section content type is post.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_recent_posts_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[recent_posts_content_type]' )->value();
	return music_zone_pro_is_recent_posts_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if recent_posts section content type is category.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_recent_posts_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[recent_posts_content_type]' )->value();
	return music_zone_pro_is_recent_posts_section_enable( $control ) && ( 'category' == $content_type );
}

/*==================Popular Posts===============*/

/**
 * Check if popular_posts section is enabled.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_popular_posts_section_enable( $control ) {
	return ( $control->manager->get_setting( 'music_zone_pro_theme_options[popular_posts_section_enable]' )->value() );
}

/**
 * Check if popular_posts section content type is page.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_popular_posts_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[popular_posts_content_type]' )->value();
	return music_zone_pro_is_popular_posts_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if popular_posts section content type is post.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_popular_posts_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[popular_posts_content_type]' )->value();
	return music_zone_pro_is_popular_posts_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if popular_posts section content type is category.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_popular_posts_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[popular_posts_content_type]' )->value();
	return music_zone_pro_is_popular_posts_section_enable( $control ) && ( 'category' == $content_type );
}

/*==================Instagram===============*/

/**
 * Check if instagram section is enabled.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_instagram_section_enable( $control ) {
	return ( $control->manager->get_setting( 'music_zone_pro_theme_options[instagram_section_enable]' )->value() );
}

/*=================Popular Products================*/

/**
 * Check if popular_products section is enabled.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_popular_products_section_enable( $control ) {
	return ( $control->manager->get_setting( 'music_zone_pro_theme_options[popular_products_section_enable]' )->value() );
}

function music_zone_pro_is_popular_products_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[popular_products_content_type]' )->value();
	return music_zone_pro_is_popular_products_section_enable( $control ) && ( 'product' == $content_type );
}

function music_zone_pro_is_popular_products_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[popular_products_content_type]' )->value();
	return music_zone_pro_is_popular_products_section_enable( $control ) && ( 'product-category' == $content_type );
}

/*=================Featured Products================*/

/**
 * Check if featured_products section is enabled.
 *
 * @since Music Zone Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function music_zone_pro_is_featured_products_section_enable( $control ) {
	return ( $control->manager->get_setting( 'music_zone_pro_theme_options[featured_products_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

/*=================Trending Product================*/

function music_zone_pro_is_trending_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'music_zone_pro_theme_options[trending_product_section_enable]' )->value() );
}

/**
 * Check if trending_product section content type is post.
 *
 * @since Businesszen Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */

function music_zone_pro_is_trending_product_section_content_category_enable_1( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[trending_content_type_1]' )->value();
	return music_zone_pro_is_trending_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}

function music_zone_pro_is_trending_product_section_content_category_enable_2( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[trending_content_type_2]' )->value();
	return music_zone_pro_is_trending_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}

function music_zone_pro_is_trending_product_section_content_category_enable_3( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[trending_content_type_3]' )->value();
	return music_zone_pro_is_trending_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}

function music_zone_pro_is_trending_product_section_content_product_enable_1( $control ) {
		$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[trending_content_type_1]' )->value();
	return music_zone_pro_is_trending_product_section_enable( $control ) && ( 'product' == $content_type );
}

function music_zone_pro_is_trending_product_section_content_product_enable_2( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[trending_content_type_2]' )->value();
	return music_zone_pro_is_trending_product_section_enable( $control ) && ( 'product' == $content_type );
}

function music_zone_pro_is_trending_product_section_content_product_enable_3( $control ) {
	$content_type = $control->manager->get_setting( 'music_zone_pro_theme_options[trending_content_type_3]' )->value();
	return music_zone_pro_is_trending_product_section_enable( $control ) && ( 'product' == $content_type );
}