<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage  Music Zone Pro
 * @since  Music Zone Pro 1.0.0
 * @return array An array of default values
 */

function music_zone_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$music_zone_pro_default_options = array(
		// Color Options
		'header_title_color'			    => '#fff',
		'header_tagline_color'			    => '#fff',
		'header_txt_logo_extra'			    => 'show-all',
		'colorscheme_hue'				    => '#d87b4d',
		'colorscheme'					    => 'default',
		'theme_version'						=> 'dark-version',
		'home_layout'						=> 'default-design',

		// typography Options
		'theme_typography' 				    => 'default',
		'body_theme_typography' 		    => 'default',
		
		// loader
		'loader_enable'         		    => (bool) false,
		'loader_icon'         			    => 'default',

		// breadcrumb
		'breadcrumb_enable'				    => (bool) true,
		'breadcrumb_separator'			    => '/',

		// homepage options
		'enable_frontpage_content' 			=> false,

		// layout 
		'site_layout'         			    => 'wide',
		'sidebar_position'         		    => 'right-sidebar',
		'post_sidebar_position' 		    => 'right-sidebar',
		'page_sidebar_position' 		    => 'right-sidebar',
		'menu_sticky'					    => (bool) false,
		'search_icon_in_primary_menu_enable'=> (bool) true,
		'enable_cart_button'                => (bool) true,
		'enable_advertisement'              => (bool) false,

		// excerpt options
		'long_excerpt_length'               => 25,

		// pagination options
		'pagination_enable'         	    => (bool) true,
		'pagination_type'         		    => 'default',

		// footer options
		'copyright_text'           		    => sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. ', '1: Year, 2: Site Title with home URL', 'music-zone-pro' ), '[the-year]', '[site-link]' ) . esc_html__( 'All Rights Reserved | ', 'music-zone-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'music-zone-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	    => (bool) true,

		// reset options
		'reset_options'      			    => (bool) false,

		// homepage sections sortable
		'sortable' 							=> 'slider,music_player,service,about,playlist,album,promotion,recent_product,event,gallery,team,counter,testimonial,latest_posts,subscription,partners,contact,featured_posts,recent_posts,popular_posts,instagram,popular_products,featured_products,trending_product',

		// default sortabl
		'default_sortable' 					=> 'slider,music_player,service,playlist,album,promotion,recent_product,event,gallery,about,team,counter,testimonial,subscription,latest_posts',

		//second sortable
		'second_sortable' 					=> 'slider,about,promotion,service,partners,gallery,team,counter,testimonial,subscription,latest_posts,contact',

		//third sortable
		'third_sortable' 					=> 'slider,featured_posts,about,recent_posts,promotion,popular_posts,recent_product,testimonial,subscription,latest_posts,instagram',

		//fourth sortable
		'fourth_sortable' 					=> 'slider,about,recent_product,promotion,popular_products,partners,featured_products,trending_product,testimonial,subscription,latest_posts',
		

		// blog/archive options,counter
		'your_latest_posts_title' 		    => esc_html__( 'Blogs', 'music-zone-pro' ),
		'read_more_text' 				    => esc_html__( 'Learn More', 'music-zone-pro' ),
		'blog_column'					    => 'col-2',
		'hide_date' 					    => (bool) false,
		'hide_category'					    => (bool) false,
		'hide_banner'					    => (bool) false,
		'hide_content' 					    => (bool) false,		


		// single post theme options
		'single_post_hide_date' 		    => (bool) false,
		'single_post_hide_author'		    => (bool) false,
		'single_post_hide_category'		    => (bool) false,
		'single_post_hide_image'			=> (bool) false,
		'single_post_hide_banner'		    => (bool) false,
		'hide_image' 					    => (bool) false,
		'single_post_hide_tags'			    => (bool) false,
		'hide_author'			   			=> (bool) false,
		'hide_date'			   				=> (bool) false,
		'hide_category'			   			=> (bool) false,

		/* Front Page */

		// Slider
		'slider_section_enable'				=> (bool) true,
		'slider_content_type'				=> 'post',
		'slider_count'						=> 3,
		'slider_autoplay_enable'			=> (bool) false,
		'slider_excerpt_length'				=> 25,
		'slider_btn_txt'                    => esc_html__('Purchase','music-zone-pro'),
		'slider_btn_alt_txt'                => esc_html__('View More','music-zone-pro'),

		//service
		'service_section_enable'		    => (bool) true,
		'service_content_type'			    =>'post',
		'service_section_title'			    => esc_html__( 'What We Do', 'music-zone-pro' ),
		'service_section_sub_title'			=> esc_html__( 'Services', 'music-zone-pro' ),
		'service_posts_count'			    => 3,
		'service_excerpt_length'			=> 20,

		
		// Playlist
        'music_player_section_enable'		    => (bool) true,
        'playlist_section_enable'		    => (bool) true,
        'playlist_title'				    => esc_html__( 'Audio Tracks', 'music-zone-pro' ),
        'playlist_subtitle'				    => esc_html__( 'Playlist', 'music-zone-pro' ),

		// album
		'album_section_enable'	            => true,
		'album_content_type'	            => 'category',
		'album_count'			            =>3,
		'album_title'			            => esc_html__( 'Latest Release', 'music-zone-pro' ),
		'album_subtitle'		            => esc_html__( 'Festival Release', 'music-zone-pro' ), 
		'album_btn_title'		            => esc_html__( 'Download Now', 'music-zone-pro' ),

		// promotion
	   'promotion_section_enable'			=> true,
	   'promotion_content_type'			    => 'page',
	   'promotion_title'					=> esc_html__( 'Maroon 6 Live Show', 'music-zone-pro' ),
	   'promotion_subtitle'				    => esc_html__( 'Music is a world within itself', 'music-zone-pro' ),
	   'promotion_description'				=> esc_html__( 'DJ Beat$’s life has been a tale of excess and indulgence. Beat$ dominated the 2000s producing hits for artists like Beyoncé, 50 Cent and Lil’ Kim. Despite his hardships, Beat$ had one of the most prolific runs of any hip-hop produce.', 'music-zone-pro' ),

		// Recent Product
		'recent_product_section_enable'		=> true,
		'recent_product_content_type'		=> 'product-category',
		'recent_product_count'				=> 4,
		'recent_product_title'				=> esc_html__( 'Shop Our Products', 'music-zone-pro' ),
		'recent_product_subtitle'			=> esc_html__( 'Discover our latest products', 'music-zone-pro' ),

		'collection_section_enable'		    => false,
		'collection_title'				    => esc_html__( 'Spring Collections', 'music-zone-pro' ),
		'collection_subtitle'			    => esc_html__( 'Discover our latest product', 'music-zone-pro' ),

		 // Gallery
		'gallery_section_enable'		    => true,
		'gallery_content_type'			    => 'category',
		'gallery_count'					    => 6,
		'gallery_title'					    => esc_html__( 'Latest Concerts', 'music-zone-pro' ),
		'gallery_subtitle'				    => esc_html__( 'Gallery', 'music-zone-pro' ),

		// About
		'about_section_enable'			    => true,
		'about_content_type'			    => 'page',
		'about_column'					    => 'col-2',
		'about_title'					    => esc_html__( 'Popular', 'music-zone-pro' ),
		'about_subtitle'				    => esc_html__( 'Artist of the Week', 'music-zone-pro' ),
		'about_description'				    => esc_html__( 'Etiam euismod pulvinar velit id commodo. Aenean id varius libLorem ipsum dolor sit amet, consectetur adipiscing elit. Etiam euismod pulvinar velit id commodo. Aenean id varius libero. Curabitur sit amet eros velit.', 'music-zone-pro' ),

		//team 
		'team_section_enable'				=> true,
		'team_content_type'					=> 'page',
		'team_count'						=> 3,
		'team_column_layout'				=> 'col-4',
		'team_title'						=> esc_html__( 'Our Talented Team', 'music-zone-pro' ),
		'team_sub_title'					=> esc_html__( 'Artists', 'music-zone-pro' ),	
		'team_btn_label'					=> esc_html__( 'View All Team', 'music-zone-pro' ),


		//counter 
		'counter_section_enable'			=> true,
		'counter_count'						=> 4,

		// testimonial
		'testimonial_section_enable'	    => true,
		'testimonial_content_type'		    => 'category',
		'testimonial_count'				    => 3,
		'testimonial_title'				    => esc_html__( 'Public Reviews', 'music-zone-pro' ),
		'testimonial_subtitle'			    => esc_html__( 'Testimonials', 'music-zone-pro' ),

		// blogs
		'latest_posts_section_enable'	    => true,
		'latest_posts_content_type'		    => 'category',
		'latest_posts_count'			    => 3,
		'latest_posts_title'			    => esc_html__( 'Our Latest Posts', 'music-zone-pro' ),
		'latest_posts_subtitle'			    => esc_html__( 'Check our latest posts, resources and more', 'music-zone-pro' ),
		'latest_posts_btn_title'		    => esc_html__( 'Learn More', 'music-zone-pro' ),

		// Event
		'event_section_enable'			    => true,
		'event_content_type'			    => 'category',
		'event_count'					    => 3,
		'event_title'					    => esc_html__( 'Upcoming Events', 'music-zone-pro' ),
		'event_subtitle'				    => esc_html__( 'Amazing shows around 2019', 'music-zone-pro' ),
		'event_readmore'				    => esc_html__( 'Buy Ticket', 'music-zone-pro' ),
		'event_btn_title'				    => esc_html__( 'View All Events', 'music-zone-pro' ),

		// Subscription
		'subscription_section_enable'	    => false,
		'subscription_title'			    => esc_html__( 'Don’t miss any updates, grab our monthly newsletter', 'music-zone-pro' ),
		'subscription_subtitle'			    => esc_html__( 'Subscribe now and stay tuned', 'music-zone-pro' ),

		//partners
		'partners_section_enable'		    => (bool) true,
		'partners_count'				    => 4,
		'partners_subtitle'				    => esc_html__( 'Our Sponsors', 'music-zone-pro' ),
		'partners_title'				    => esc_html__( 'Trusted Clients', 'music-zone-pro' ),

		// contact
		'contact_section_enable'			=> (bool) true,
		'contact_section_subtitle'          => esc_html__('Contact Us','music-zone-pro'),
		'contact_section_title'			    => esc_html__( 'Get Free SEO Analysis', 'music-zone-pro' ),
		'contact_section_phone_number'	    => '+15 2589631471',
		'contact_section_address'			=> esc_html__( '8565 Avenue Street, United States', 'music-zone-pro' ),
		'contact_section_email'			    => 'info@gmail.com',

		//featured_posts 
		'featured_posts_section_enable'		=> (bool) true,
		'featured_posts_count'				=> 3,
		'featured_posts_content_type'		=> 'post',

		//recent_posts 
		'recent_posts_section_enable'		=> (bool) true,
		'recent_posts_count'				=> 3,
		'recent_posts_content_type'			=> 'post',
		'recent_posts_column_layout'		=> 'col-3',
		'recent_posts_excerpt_length'		=> 15,
		'recent_posts_title'				=> esc_html__( 'Lighting to Create Art', 'music-zone-pro' ),
		'recent_posts_sub_title'			=> esc_html__( 'Recent Posts', 'music-zone-pro' ),

		//popular posts 
		'popular_posts_section_enable'		=> (bool) true,
		'popular_posts_count'				=> 3,
		'popular_posts_content_type'		=> 'post',
		'popular_posts_excerpt_length'		=> 15,
		'popular_posts_title'				=> esc_html__( 'Lighting to Create Art', 'music-zone-pro' ),
		'popular_posts_sub_title'			=> esc_html__( 'Popular Posts', 'music-zone-pro' ),

		//instagram
		'instagram_section_enable' 		     => (bool) true,
		'instagram_section_sub_title'	     =>	esc_html__('Follow on', 'music-zone-pro'),
		'instagram_section_title'		     =>	esc_html__('Instagram', 'music-zone-pro'),
		'instagram_section_shortcode'	     =>	'[instagram-feed showheader=false num=6 cols=6 showfollow=false imagepadding=0 showbutton=false]',

		//popular products
		'popular_products_section_enable'   => true,
		'popular_products_content_type'	    => 'product-category',
		'popular_products_count'		    => 3,
		'popular_products_col'			    => 'columns-3',
		'popular_products_title'		    => esc_html__( 'Popular Products', 'music-zone-pro' ),
		'popular_products_sub_title'	    => esc_html__( 'Onlne', 'music-zone-pro' ),

		//featured_products
		'featured_products_section_enable'  => (bool) true,
		'featured_products_count'		    => 2,

		//trending_product 
		'trending_product_section_enable'   => (bool) true,
		'trending_product_count'		    => 3,

	);

$output = apply_filters( 'music_zone_pro_default_theme_options', $music_zone_pro_default_options );

	// Sort array in ascending order, according to the key:
if ( ! empty( $output ) ) {
	ksort( $output );
}

return $output;
}