<?php
/**
 * About Section options
 *
 * @package Theme Palace
 * @subpackage Music Zone Pro
 * @since Music Zone Pro 1.0.0
 */

// Add About section
$wp_customize->add_section( 'music_zone_pro_about_section', array(
	'title'             => esc_html__( 'About Us','music-zone-pro' ),
	'description'       => esc_html__( 'About Section options.', 'music-zone-pro' ),
	'panel'             => 'music_zone_pro_front_page_panel',
	'active_callback'   => function( $control ) {
		return (
			music_zone_pro_is_default_layout( $control )
			||
			music_zone_pro_is_second_layout( $control )
			||
			music_zone_pro_is_third_layout( $control )
			||
			music_zone_pro_is_fourth_layout( $control )
		);
	},
) );

// About content enable control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[about_section_enable]', array(
	'default'			=> 	$options['about_section_enable'],
	'sanitize_callback' => 'music_zone_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Music_Zone_Pro_Switch_Control( $wp_customize, 'music_zone_pro_theme_options[about_section_enable]', array(
	'label'             => esc_html__( 'About Section Enable', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_about_section',
	'on_off_label' 		=> music_zone_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[about_section_enable]', array(
		'selector'      => '.about-section .tooltiptext',
		'settings'      => 'music_zone_pro_theme_options[about_section_enable]',
    ) );
}

// about subtitle setting and control
$wp_customize->add_setting( 'music_zone_pro_theme_options[about_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[about_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'music-zone-pro' ),
	'section'        	=> 'music_zone_pro_about_section',
	'active_callback' 	=> 'music_zone_pro_is_about_section_enable',
	'type'				=> 'text',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[about_subtitle]', array(
		'selector'            => '#music_zone_pro_about_section p.section-subtitle',
		'settings'            => 'music_zone_pro_theme_options[about_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'music_zone_pro_about_subtitle_partial',
    ) );
}


// About content type control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[about_content_type]', array(
	'default'          	=> $options['about_content_type'],
	'sanitize_callback' => 'music_zone_pro_sanitize_select',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[about_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_about_section',
	'type'				=> 'select',
	'active_callback' 	=> 'music_zone_pro_is_about_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'music-zone-pro' ),
		'post' 		=> esc_html__( 'Post', 'music-zone-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'music-zone-pro' ),
	),
) );

// about pages drop down chooser control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[about_content_page]', array(
	'sanitize_callback' => 'music_zone_pro_sanitize_page',
) );

$wp_customize->add_control( new Music_Zone_Pro_Dropdown_Chooser( $wp_customize, 'music_zone_pro_theme_options[about_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_about_section',
	'choices'			=> music_zone_pro_page_choices(),
	'active_callback'	=> 'music_zone_pro_is_about_section_content_page_enable',
) ) );

// about posts drop down chooser control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[about_content_post]', array(
	'sanitize_callback' => 'music_zone_pro_sanitize_page',
) );

$wp_customize->add_control( new Music_Zone_Pro_Dropdown_Chooser( $wp_customize, 'music_zone_pro_theme_options[about_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_about_section',
	'choices'			=> music_zone_pro_post_choices(),
	'active_callback'	=> 'music_zone_pro_is_about_section_content_post_enable',
) ) );

// about title setting and control
$wp_customize->add_setting( 'music_zone_pro_theme_options[about_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_title'],
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[about_title]', array(
	'label'           	=> esc_html__( 'Title', 'music-zone-pro' ),
	'section'        	=> 'music_zone_pro_about_section',
	'active_callback' 	=> 'music_zone_pro_is_about_section_content_custom_enable',
	'type'				=> 'text',
) );

// about description setting and control
$wp_customize->add_setting( 'music_zone_pro_theme_options[about_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['about_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[about_description]', array(
	'label'           	=> esc_html__( 'Description', 'music-zone-pro' ),
	'section'        	=> 'music_zone_pro_about_section',
	'active_callback' 	=> 'music_zone_pro_is_about_section_content_custom_enable',
	'type'				=> 'textarea',
) );



// about image setting and control.
$wp_customize->add_setting( 'music_zone_pro_theme_options[about_image]', array(
	'sanitize_callback' => 'music_zone_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'music_zone_pro_theme_options[about_image]',
		array(
		'label'       		=> esc_html__( 'Image', 'music-zone-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'music-zone-pro' ), 512, 520 ),
		'section'     		=> 'music_zone_pro_about_section',
		'active_callback'	=> 'music_zone_pro_is_about_section_content_custom_enable',
) ) );

// about btn title setting and control
$wp_customize->add_setting( 'music_zone_pro_theme_options[about_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[about_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'music-zone-pro' ),
	'section'        	=> 'music_zone_pro_about_section',
	'active_callback' 	=> 'music_zone_pro_is_about_section_enable',
	'type'				=> 'text',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[about_btn_title]', array(
		'selector'            => '#music_zone_pro_about_section .read-more .btn',
		'settings'            => 'music_zone_pro_theme_options[about_btn_title]',
    ) );
}



// about btn link setting and control
$wp_customize->add_setting( 'music_zone_pro_theme_options[about_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[about_btn_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'music-zone-pro' ),
	'section'        	=> 'music_zone_pro_about_section',
	'active_callback' 	=> 'music_zone_pro_is_about_section_content_custom_enable',
	'type'				=> 'url',
) );


