<?php
/**
 * Recent album options
 *
 * @package Theme Palace
 * @subpackage Music Zone Pro
 * @since Music Zone Pro 1.0.0
 */

// Add Recent Album section
$wp_customize->add_section( 'music_zone_pro_album_section', array(
	'title'             => esc_html__( 'Recent Album','music-zone-pro' ),
	'description'       => esc_html__( 'Recent Album Section options.', 'music-zone-pro' ),
	'panel'             => 'music_zone_pro_front_page_panel',
	'active_callback'   => function( $control ) {
		return (
			music_zone_pro_is_default_layout( $control )
		);
	},
) );

// Recent Album content enable control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[album_section_enable]', array(
	'default'			=> 	$options['album_section_enable'],
	'sanitize_callback' => 'music_zone_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Music_Zone_Pro_Switch_Control( $wp_customize, 'music_zone_pro_theme_options[album_section_enable]', array(
	'label'             => esc_html__( 'Recent Album Section Enable', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_album_section',
	'on_off_label' 		=> music_zone_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[album_section_enable]', array(
		'selector'      => '.album-section .tooltiptext',
		'settings'      => 'music_zone_pro_theme_options[album_section_enable]',
    ) );
}


// album title setting and control
$wp_customize->add_setting( 'music_zone_pro_theme_options[album_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['album_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[album_title]', array(
	'label'           	=> esc_html__( 'Title', 'music-zone-pro' ),
	'section'        	=> 'music_zone_pro_album_section',
	'active_callback' 	=> 'music_zone_pro_is_album_section_enable',
	'type'				=> 'text',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[album_title]', array(
		'selector'      => '#music_zone_pro_album_section .section-header .section-title',
		'settings'      => 'music_zone_pro_theme_options[album_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'music_zone_pro_album_title_partial',
    ) );
}


// album subtitle setting and control
$wp_customize->add_setting( 'music_zone_pro_theme_options[album_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['album_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[album_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'music-zone-pro' ),
	'section'        	=> 'music_zone_pro_album_section',
	'active_callback' 	=> 'music_zone_pro_is_album_section_enable',
	'type'				=> 'text',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[album_subtitle]', array(
		'selector'      => '#music_zone_pro_album_section .section-header .section-subtitle',
		'settings'      => 'music_zone_pro_theme_options[album_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'music_zone_pro_album_subtitle_partial',
    ) );
}


// album btn_title setting and control
$wp_customize->add_setting( 'music_zone_pro_theme_options[album_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['album_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[album_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'music-zone-pro' ),
	'section'        	=> 'music_zone_pro_album_section',
	'active_callback' 	=> 'music_zone_pro_is_album_section_enable',
	'type'				=> 'text',
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[album_count]', array(
	'default'          	=> $options['album_count'],
	'sanitize_callback' => 'music_zone_pro_sanitize_number_range',
	'validate_callback' => 'music_zone_pro_validate_album_count',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[album_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'music-zone-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 30. Please input the valid number and save. Then refresh the page to see the change.', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_album_section',
	'active_callback'   => 'music_zone_pro_is_album_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 30,
		'style' => 'width: 100px;'
		),
) );

// album posts drop down chooser control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[album_hr]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( new Music_Zone_Pro_Customize_Horizontal_Line( $wp_customize, 'music_zone_pro_theme_options[album_hr]', array(
	'type'				=> 'hr',
	'section'           => 'music_zone_pro_album_section',
	'active_callback'	=> 'music_zone_pro_is_album_section_enable',
) ) );

// Recent Album content type control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[album_content_type]', array(
	'default'          	=> $options['album_content_type'],
	'sanitize_callback' => 'music_zone_pro_sanitize_select',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[album_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_album_section',
	'type'				=> 'select',
	'active_callback' 	=> 'music_zone_pro_is_album_section_enable',
	'choices'			=> music_zone_pro_album_content_type(),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'music_zone_pro_theme_options[album_content_category]', array(
	'sanitize_callback' => 'music_zone_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Music_Zone_Pro_Dropdown_Taxonomies_Control( $wp_customize,'music_zone_pro_theme_options[album_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'music-zone-pro' ),
	'description'      	=> esc_html__( 'Note: Latest three posts will be shown from selected category', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_album_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'music_zone_pro_is_album_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'music_zone_pro_theme_options[album_content_product_category]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Music_Zone_Pro_Dropdown_Taxonomies_Control( $wp_customize,'music_zone_pro_theme_options[album_content_product_category]', array(
	'label'             => esc_html__( 'Select Product Category', 'music-zone-pro' ),
	'description'      	=> esc_html__( 'Note: Latest three posts will be shown from selected category', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_album_section',
	'taxonomy'			=> 'product_cat',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'music_zone_pro_is_album_section_content_product_category_enable'
) ) );	

for ( $i = 1; $i <= $options['album_count']; $i++ ) :

	// album posts drop down chooser control and setting
	$wp_customize->add_setting( 'music_zone_pro_theme_options[album_content_page_' . $i . ']', array(
		'sanitize_callback' => 'music_zone_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Music_Zone_Pro_Dropdown_Chooser( $wp_customize, 'music_zone_pro_theme_options[album_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'music-zone-pro' ), $i ),
		'section'           => 'music_zone_pro_album_section',
		'choices'			=> music_zone_pro_page_choices(),
		'active_callback'	=> 'music_zone_pro_is_album_section_content_page_enable',
	) ) );

	// album posts drop down chooser control and setting
	$wp_customize->add_setting( 'music_zone_pro_theme_options[album_content_post_' . $i . ']', array(
		'sanitize_callback' => 'music_zone_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Music_Zone_Pro_Dropdown_Chooser( $wp_customize, 'music_zone_pro_theme_options[album_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'music-zone-pro' ), $i ),
		'section'           => 'music_zone_pro_album_section',
		'choices'			=> music_zone_pro_post_choices(),
		'active_callback'	=> 'music_zone_pro_is_album_section_content_post_enable',
	) ) );

	// album posts drop down chooser control and setting
	$wp_customize->add_setting( 'music_zone_pro_theme_options[album_content_product_' . $i . ']', array(
		'sanitize_callback' => 'music_zone_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Music_Zone_Pro_Dropdown_Chooser( $wp_customize, 'music_zone_pro_theme_options[album_content_product_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Product %d', 'music-zone-pro' ), $i ),
		'section'           => 'music_zone_pro_album_section',
		'choices'			=> music_zone_pro_product_choices(),
		'active_callback'	=> 'music_zone_pro_is_album_section_content_product_enable',
	) ) );

	// album subtitle setting and control
	$wp_customize->add_setting( 'music_zone_pro_theme_options[album_post_subtitle_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'music_zone_pro_theme_options[album_post_subtitle_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Post Sub Title %d', 'music-zone-pro' ), $i ),
		'section'        	=> 'music_zone_pro_album_section',
		'active_callback' 	=> 'music_zone_pro_is_album_section_enable',
		'type'				=> 'text',
	) );

endfor;
