<?php
/**
 * Contact Section options
 *
 * @package Theme Palace
 * @subpackage  Music Zone Pro
 * @since  Music Zone Pro 1.0.0
 */

// Add Contact section
$wp_customize->add_section( 'music_zone_pro_contact_section', 
    array(
        'title'             => esc_html__( 'Contact us','music-zone-pro' ),
        'description'       => esc_html__( 'Contact us  Section options.', 'music-zone-pro' ),
        'panel'             => 'music_zone_pro_front_page_panel',
        'active_callback'   => function( $control ) {
            return ( 
                music_zone_pro_is_second_layout( $control )
            );
        },
    ) 
);

// Contact content enable control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[contact_section_enable]', 
    array(
        'default'			=> 	$options['contact_section_enable'],
        'sanitize_callback' => 'music_zone_pro_sanitize_switch_control',
    ) 
);

$wp_customize->add_control( new  Music_Zone_Pro_Switch_Control( $wp_customize,
    'music_zone_pro_theme_options[contact_section_enable]',
        array(
            'label'             => esc_html__( 'Contact Section Enable', 'music-zone-pro' ),
            'section'           => 'music_zone_pro_contact_section',
            'on_off_label' 		=> music_zone_pro_switch_options(),
        ) 
    )
);

// contact section title control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[contact_section_subtitle]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'			=> 	$options['contact_section_subtitle'],
        'transport'			=>'postMessage'
    ) 
);

$wp_customize->add_control('music_zone_pro_theme_options[contact_section_subtitle]',
    array(
        'label'             => esc_html__( 'Section Sub Title', 'music-zone-pro' ),
        'section'           => 'music_zone_pro_contact_section',
        'type'              => 'text',
        'active_callback'	=> 'music_zone_pro_is_contact_section_enable',
    )
);

$wp_customize->selective_refresh->add_partial(
    'music_zone_pro_theme_options[contact_section_subtitle]',
    array(
        'selector'            => '#music_zone_pro_contact_section .section-subtitle',
        'render_callback'     => 'music_zone_pro_contact_section_subtitle_partial',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'music_zone_pro_contact_section_subtitle_partial',
    )
);

// contact section title control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[contact_section_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'			=> 	$options['contact_section_title'],
        'transport'			=>'postMessage'
    ) 
);

$wp_customize->add_control('music_zone_pro_theme_options[contact_section_title]',
    array(
        'label'             => esc_html__( 'Section Title', 'music-zone-pro' ),
        'section'           => 'music_zone_pro_contact_section',
        'type'              => 'text',
        'active_callback'	=> 'music_zone_pro_is_contact_section_enable',
    )
);

$wp_customize->selective_refresh->add_partial(
    'music_zone_pro_theme_options[contact_section_title]',
    array(
        'selector'            => '#music_zone_pro_contact_section .section-title',
        'render_callback'     => 'music_zone_pro_contact_section_title_partial',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'music_zone_pro_contact_section_title_partial',
    )
);

// contact section title control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[contact_section_shortcode]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=>'refresh'
    ) 
);

$wp_customize->add_control('music_zone_pro_theme_options[contact_section_shortcode]',
    array(
        'label'             => esc_html__( 'Contact Form Shortcode', 'music-zone-pro' ),
        'description'       => sprintf( music_zone_pro_santize_allow_tag('<a href="%1$s" target="_blank">click here </a> to get contact form 7 shortcode.', 'music-zone-pro'), admin_url( $paths = '?page=wpcf7', $scheme = 'admin' ) ),
        'section'           => 'music_zone_pro_contact_section',
        'type'              => 'text',
        'active_callback'	=> 'music_zone_pro_is_contact_section_enable',
    )
);

//contact_section_address
$wp_customize->add_setting('music_zone_pro_theme_options[contact_section_address]',
array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['contact_section_address'],
    )
);

$wp_customize->add_control('music_zone_pro_theme_options[contact_section_address]',
    array(
        'section'           => 'music_zone_pro_contact_section',
        'label'             => esc_html__( 'Address:', 'music-zone-pro' ),
        'type'              =>'text',
        'active_callback'   => 'music_zone_pro_is_contact_section_enable'
    )
);

//contact_section_phone_number
$wp_customize->add_setting('music_zone_pro_theme_options[contact_section_phone_number]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['contact_section_phone_number'],
    )
);

$wp_customize->add_control('music_zone_pro_theme_options[contact_section_phone_number]',
    array(
        'section'			=> 'music_zone_pro_contact_section',
        'label'				=> esc_html__( 'Contact Number:', 'music-zone-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'music_zone_pro_is_contact_section_enable'
    )
);

//contact_section_email
$wp_customize->add_setting('music_zone_pro_theme_options[contact_section_email]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['contact_section_email'],
    )
);

$wp_customize->add_control('music_zone_pro_theme_options[contact_section_email]',
    array(
        'section'			=> 'music_zone_pro_contact_section',
        'label'				=> esc_html__( 'E-mail:', 'music-zone-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'music_zone_pro_is_contact_section_enable'
    )
);