<?php
/**
 * Counter Section options
 *
 * @package Theme Palace
 * @subpackage Music Zone Pro
 * @since Music Zone Pro 1.0.0
 */
$options = music_zone_pro_get_theme_options();
// Add Counter section
$wp_customize->add_section( 'music_zone_pro_counter_section', array(
	'title'             => esc_html__( 'Counters','music-zone-pro' ),
	'description'       => esc_html__( 'Counters Section options.', 'music-zone-pro' ),
	'panel'             => 'music_zone_pro_front_page_panel',
	'active_callback'   => function( $control ) {
		return (
			music_zone_pro_is_default_layout( $control )
			||
			music_zone_pro_is_second_layout( $control )
		);
	},
) );

// Counter content enable control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[counter_section_enable]', array(
	'default'			=> 	$options['counter_section_enable'],
	'sanitize_callback' => 'music_zone_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Music_Zone_Pro_Switch_Control( $wp_customize, 'music_zone_pro_theme_options[counter_section_enable]', array(
	'label'             => esc_html__( 'Counter Section Enable', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_counter_section',
	'on_off_label' 		=> music_zone_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[counter_section_enable]', array(
		'selector'       => '.counter-section .tooltiptext',
		'settings'       => 'music_zone_pro_theme_options[counter_section_enable]',
    ) );
}


// Counter image control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[counter_image]', array(
	'sanitize_callback' => 'music_zone_pro_sanitize_image',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'music_zone_pro_theme_options[counter_image]',
		array(
		'label'         => esc_html__( 'Image', 'music-zone-pro' ),
		'description'   => sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'music-zone-pro' ), 1350, 385 ),
		'section'       => 'music_zone_pro_counter_section',
		'active_callback'	=> 'music_zone_pro_is_counter_section_enable',
) ) );

// Event social icons number control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[counter_count]', array(
	'default'          	=> $options['counter_count'],
	'sanitize_callback' => 'music_zone_pro_sanitize_number_range',
	'validate_callback' => 'music_zone_pro_validate_counter_count'
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[counter_count]', array(
	'label'             => esc_html__( 'Number of Counters', 'music-zone-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_counter_section',
	'type'				=> 'number',
	'active_callback'	=> 'music_zone_pro_is_counter_section_enable',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['counter_count']; $i++ ) :

	// counter note control and setting
	$wp_customize->add_setting( 'music_zone_pro_theme_options[counter_content_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Music_Zone_Pro_Icon_Picker( $wp_customize, 'music_zone_pro_theme_options[counter_content_icon_' . $i . ']', array(
		'label'    => sprintf( esc_html__( 'Select Icon %d', 'music-zone-pro' ), $i ),
		'section'  => 'music_zone_pro_counter_section',
		'active_callback'	=> 'music_zone_pro_is_counter_section_enable',
	) ) );

	if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[counter_content_icon_' . $i . ']', array(
		'selector'  => '#music_zone_pro_counter_section .counter_content_icon_'.$i,
		'settings'  => 'music_zone_pro_theme_options[counter_content_icon_' . $i . ']',
    ) );
}

	// counter title setting and control
	$wp_customize->add_setting( 'music_zone_pro_theme_options[counter_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'music_zone_pro_theme_options[counter_title_' . $i . ']', array(
		'label'       => sprintf( esc_html__( 'Counter Title %d', 'music-zone-pro' ), $i ),
		'section'     => 'music_zone_pro_counter_section',
		'type'        => 'text',
		'active_callback'	=> 'music_zone_pro_is_counter_section_enable',
	) );

	if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[counter_title_' . $i . ']', array(
		'selector'    => '#music_zone_pro_counter_section .counter_title_'.$i,
		'settings'    => 'music_zone_pro_theme_options[counter_title_' . $i . ']',
    ) );
}

	// counter title setting and control
	$wp_customize->add_setting( 'music_zone_pro_theme_options[counter_number_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'music_zone_pro_theme_options[counter_number_' . $i . ']', array(
		'label'      => sprintf( esc_html__( 'Counter Count %d', 'music-zone-pro' ), $i ),
		'section'    => 'music_zone_pro_counter_section',
		'type'       => 'text',
		'active_callback'	=> 'music_zone_pro_is_counter_section_enable',
	) );

	if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[counter_number_' . $i . ']', array(
		'selector'  => '#music_zone_pro_counter_section .counter_number_'.$i,
		'settings'  => 'music_zone_pro_theme_options[counter_number_' . $i . ']',
    ) );
}

	// counter hr setting and control
	$wp_customize->add_setting( 'music_zone_pro_theme_options[counter_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Music_Zone_Pro_Customize_Horizontal_Line( $wp_customize, 'music_zone_pro_theme_options[counter_hr_'. $i .']',
		array(
			'section' => 'music_zone_pro_counter_section',
			'type'    => 'hr',
			'active_callback'	=> 'music_zone_pro_is_counter_section_enable',
	) ) );
endfor;



