<?php
/**
 * Event Section options
 *
 * @package Theme Palace
 * @subpackage Music Zone Pro
 * @since Music Zone Pro 1.0.0
 */

// Add Event section
$wp_customize->add_section( 'music_zone_pro_events_section', array(
	'title'             => esc_html__( 'Event','music-zone-pro' ),
	'description'       => esc_html__( 'Event Section options.', 'music-zone-pro' ),
	'panel'             => 'music_zone_pro_front_page_panel',
	'active_callback'   => function( $control ) {
		return (
			music_zone_pro_is_default_layout( $control )
		);
	},
) );

// Event content enable control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[event_section_enable]', array(
	'default'			=> 	$options['event_section_enable'],
	'sanitize_callback' => 'music_zone_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Music_Zone_Pro_Switch_Control( $wp_customize, 'music_zone_pro_theme_options[event_section_enable]', array(
	'label'             => esc_html__( 'Event Section Enable', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_events_section',
	'on_off_label' 		=> music_zone_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[event_section_enable]', array(
		'selector'            => '#music_zone_pro_events_section .tooltiptext',
		'settings'            => 'music_zone_pro_theme_options[event_section_enable]',
    ) );
}

// Event background image control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[event_bg_image]', array(
	'sanitize_callback' => 'music_zone_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'music_zone_pro_theme_options[event_bg_image]',
		array(
		'label'       		=> esc_html__( 'Bg Image', 'music-zone-pro' ),
		'section'     		=> 'music_zone_pro_events_section',
		'active_callback'	=> 'music_zone_pro_is_event_section_enable',
) ) );


// event title setting and control
$wp_customize->add_setting( 'music_zone_pro_theme_options[event_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['event_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[event_title]', array(
	'label'           	=> esc_html__( 'Title', 'music-zone-pro' ),
	'section'        	=> 'music_zone_pro_events_section',
	'active_callback' 	=> 'music_zone_pro_is_event_section_enable',
	'type'				=> 'text',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[event_title]', array(
		'selector'            => '#music_zone_pro_events_section .section-title',
		'settings'            => 'music_zone_pro_theme_options[event_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'music_zone_pro_event_title_partial',
    ) );
}


// event subtitle setting and control
$wp_customize->add_setting( 'music_zone_pro_theme_options[event_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['event_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[event_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'music-zone-pro' ),
	'section'        	=> 'music_zone_pro_events_section',
	'active_callback' 	=> 'music_zone_pro_is_event_section_enable',
	'type'				=> 'text',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[event_subtitle]', array(
		'selector'            => '#music_zone_pro_events_section .section-subtitle',
		'settings'            => 'music_zone_pro_theme_options[event_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'music_zone_pro_event_subtitle_partial',
    ) );
}


// event readmore setting and control
$wp_customize->add_setting( 'music_zone_pro_theme_options[event_readmore]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['event_readmore'],
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[event_readmore]', array(
	'label'           	=> esc_html__( 'Read More Label', 'music-zone-pro' ),
	'section'        	=> 'music_zone_pro_events_section',
	'active_callback' 	=> 'music_zone_pro_is_event_section_enable',
	'type'				=> 'text',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[event_readmore]', array(
		'selector'            => '#music_zone_pro_events_section .buy-ticket .btn',
		'settings'            => 'music_zone_pro_theme_options[event_readmore]',
    ) );
}

// Event content type control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[event_content_type]', array(
	'default'          	=> $options['event_content_type'],
	'sanitize_callback' => 'music_zone_pro_sanitize_select',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[event_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_events_section',
	'type'				=> 'select',
	'active_callback' 	=> 'music_zone_pro_is_event_section_enable',
	'choices'			=> music_zone_pro_event_content_type(),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[event_count]', array(
	'default'          	=> $options['event_count'],
	'sanitize_callback' => 'music_zone_pro_sanitize_number_range',
	'validate_callback' => 'music_zone_pro_validate_event_count',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[event_count]', array(
	'label'             => esc_html__( 'Number of Event', 'music-zone-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_events_section',
	'active_callback'   => 'music_zone_pro_is_event_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['event_count']; $i++ ) :

	// event posts drop down chooser control and setting
	$wp_customize->add_setting( 'music_zone_pro_theme_options[event_content_page_' . $i . ']', array(
		'sanitize_callback' => 'music_zone_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Music_Zone_Pro_Dropdown_Chooser( $wp_customize, 'music_zone_pro_theme_options[event_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'music-zone-pro' ), $i ),
		'section'           => 'music_zone_pro_events_section',
		'choices'			=> music_zone_pro_page_choices(),
		'active_callback'	=> 'music_zone_pro_is_event_section_content_page_enable',
	) ) );

	// event posts drop down chooser control and setting
	$wp_customize->add_setting( 'music_zone_pro_theme_options[event_content_post_' . $i . ']', array(
		'sanitize_callback' => 'music_zone_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Music_Zone_Pro_Dropdown_Chooser( $wp_customize, 'music_zone_pro_theme_options[event_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'music-zone-pro' ), $i ),
		'section'           => 'music_zone_pro_events_section',
		'choices'			=> music_zone_pro_post_choices(),
		'active_callback'	=> 'music_zone_pro_is_event_section_content_post_enable',
	) ) );

	// event posts drop down chooser control and setting
	$wp_customize->add_setting( 'music_zone_pro_theme_options[event_content_event_' . $i . ']', array(
		'sanitize_callback' => 'music_zone_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Music_Zone_Pro_Dropdown_Chooser( $wp_customize, 'music_zone_pro_theme_options[event_content_event_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Event %d', 'music-zone-pro' ), $i ),
		'section'           => 'music_zone_pro_events_section',
		'choices'			=> music_zone_pro_event_choices(),
		'active_callback'	=> 'music_zone_pro_is_event_section_content_event_enable',
	) ) );

	// event location setting and control
	$wp_customize->add_setting( 'music_zone_pro_theme_options[event_location_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'music_zone_pro_theme_options[event_location_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Event Location %d', 'music-zone-pro' ), $i ),
		'section'        	=> 'music_zone_pro_events_section',
		'active_callback' 	=> 'music_zone_pro_is_event_section_enable',
		'type'				=> 'text',
	) );


endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'music_zone_pro_theme_options[event_content_category]', array(
	'sanitize_callback' => 'music_zone_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Music_Zone_Pro_Dropdown_Taxonomies_Control( $wp_customize,'music_zone_pro_theme_options[event_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'music-zone-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_events_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'music_zone_pro_is_event_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'music_zone_pro_theme_options[event_content_event_category]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Music_Zone_Pro_Dropdown_Taxonomies_Control( $wp_customize,'music_zone_pro_theme_options[event_content_event_category]', array(
	'label'             => esc_html__( 'Select Event Category', 'music-zone-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_events_section',
	'taxonomy'			=> 'tp-event-category',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'music_zone_pro_is_event_section_content_event_category_enable'
) ) );