<?php
/**
 * Featured Posts Section options
 *
 * @package Theme Palace
 * @subpackage Featured Posts
 * @since Featured Posts 1.0.0
 */

// Add Featured Posts section
$wp_customize->add_section( 'music_zone_pro_featured_posts_section', array(
	'title'             => esc_html__( 'Featured Posts','music-zone-pro' ),
	'description'       => esc_html__( 'Featured Posts Section options.', 'music-zone-pro' ),
	'panel'             => 'music_zone_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return ( 
            music_zone_pro_is_third_layout( $control )
        );
    },
) );

// Featured Posts content enable control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[featured_posts_section_enable]', array(
	'default'			=> 	$options['featured_posts_section_enable'],
	'sanitize_callback' => 'music_zone_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Music_Zone_Pro_Switch_Control( $wp_customize, 'music_zone_pro_theme_options[featured_posts_section_enable]', array(
	'label'             => esc_html__( 'Featured Posts Section Enable', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_featured_posts_section',
	'on_off_label' 		=> music_zone_pro_switch_options(),
) ) );

// Event social icons number control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[featured_posts_count]', array(
	'default'          	=> $options['featured_posts_count'],
	'sanitize_callback' => 'music_zone_pro_sanitize_number_range',
	'validate_callback' => 'music_zone_pro_validate_featured_posts_count',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[featured_posts_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'music-zone-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 50. Please input the valid number and save. Then refresh the page to see the change.', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_featured_posts_section',
	'active_callback'   => 'music_zone_pro_is_featured_posts_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 50,
		'style' => 'width: 100px;'
		),
) );

// Featured Posts content type control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[featured_posts_content_type]', array(
	'default'          	=> $options['featured_posts_content_type'],
	'sanitize_callback' => 'music_zone_pro_sanitize_select',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[featured_posts_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_featured_posts_section',
	'type'				=> 'select',
	'active_callback' 	=> 'music_zone_pro_is_featured_posts_section_enable',
	'choices'			=> array(
            'page'      => esc_html__( 'Page', 'music-zone-pro' ),
            'post'      => esc_html__( 'Post', 'music-zone-pro' ),
            'category'  => esc_html__( 'Category', 'music-zone-pro' ),
        )
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'music_zone_pro_theme_options[featured_posts_content_category]', array(
	'sanitize_callback' => 'music_zone_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Music_Zone_Pro_Dropdown_Taxonomies_Control( $wp_customize,'music_zone_pro_theme_options[featured_posts_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'music-zone-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_featured_posts_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'music_zone_pro_is_featured_posts_section_content_category_enable'
) ) );

for ( $i = 1; $i <= $options['featured_posts_count']; $i++ ) :

	// featured_posts pages drop down chooser control and setting
	$wp_customize->add_setting( 'music_zone_pro_theme_options[featured_posts_content_page_' . $i . ']', array(
		'sanitize_callback' => 'music_zone_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Music_Zone_Pro_Dropdown_Chooser( $wp_customize, 'music_zone_pro_theme_options[featured_posts_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'music-zone-pro' ), $i ),
		'section'           => 'music_zone_pro_featured_posts_section',
		'choices'			=> music_zone_pro_page_choices(),
		'active_callback'	=> 'music_zone_pro_is_featured_posts_section_content_page_enable',
	) ) );

	// featured_posts posts drop down chooser control and setting
	$wp_customize->add_setting( 'music_zone_pro_theme_options[featured_posts_content_post_' . $i . ']', array(
		'sanitize_callback' => 'music_zone_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Music_Zone_Pro_Dropdown_Chooser( $wp_customize, 'music_zone_pro_theme_options[featured_posts_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'music-zone-pro' ), $i ),
		'section'           => 'music_zone_pro_featured_posts_section',
		'choices'			=> music_zone_pro_post_choices(),
		'active_callback'	=> 'music_zone_pro_is_featured_posts_section_content_post_enable',
	) ) );

endfor;