<?php
/**
 * Instagram Section options
 *
 * @package Theme Palace
 * @subpackage Music Zone Pro
 * @since Music Zone Pro 1.0.0
 */

// Instagram section
$wp_customize->add_section('music_zone_pro_instagram_section',
	array(
		'title'         => esc_html__( 'Instagram', 'music-zone-pro' ),
		'description'   => sprintf( esc_html__( '%1$s Smash Balloon Social Photo Feed %2$s should be active and site should be connected to instagram account for this section to work.', 'music-zone-pro' ), '<a target="_blank" href="https://wordpress.org/plugins/instagram-feed/">', '</a>' ),
		'panel'         => 'music_zone_pro_front_page_panel',
		'active_callback'   => function( $control ) {
			return (
				music_zone_pro_is_third_layout( $control )
			);
		},
	)
);

// Instagram enable setting
$wp_customize->add_setting('music_zone_pro_theme_options[instagram_section_enable]',
    array(
        'sanitize_callback' => 'music_zone_pro_sanitize_switch_control',
        'default'           => $options['instagram_section_enable'],
    )
);

$wp_customize->add_control(new Music_Zone_Pro_Switch_Control($wp_customize,
    'music_zone_pro_theme_options[instagram_section_enable]',
        array(
            'section'		=> 'music_zone_pro_instagram_section',
            'label'			=> esc_html__( 'Enable instagram.', 'music-zone-pro' ),
            'on_off_label'  => music_zone_pro_switch_options(),
        )
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[instagram_section_enable]',
        array(
            'selector'            => '#instagram-section .tooltiptext',
            'settings'            => 'music_zone_pro_theme_options[instagram_section_enable]',
        )
    );
}

// Subscribe title setting
$wp_customize->add_setting('music_zone_pro_theme_options[instagram_section_sub_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['instagram_section_sub_title'],
        'transport'	        => 'postMessage',
    )
);

$wp_customize->add_control('music_zone_pro_theme_options[instagram_section_sub_title]',
    array(
        'section'		    => 'music_zone_pro_instagram_section',
        'label'			    => esc_html__( 'Section Title:', 'music-zone-pro' ),
        'active_callback'   => 'music_zone_pro_is_instagram_section_enable',
        'type'              => 'text'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[instagram_section_sub_title]',
		array(
			'selector'            => '#music_zone_pro_instagram_section p.section-subtitle',
			'settings'            => 'music_zone_pro_theme_options[instagram_section_sub_title]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'music_zone_pro_instagram_section_sub_title_partial',
		) 
	);
}

// Subscribe title setting
$wp_customize->add_setting('music_zone_pro_theme_options[instagram_section_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['instagram_section_title'],
        'transport'	        => 'postMessage',
    )
);

$wp_customize->add_control('music_zone_pro_theme_options[instagram_section_title]',
    array(
        'section'		    => 'music_zone_pro_instagram_section',
        'label'			    => esc_html__( 'Section Title:', 'music-zone-pro' ),
        'active_callback'   => 'music_zone_pro_is_instagram_section_enable',
        'type'              =>'text'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[instagram_section_title]',
		array(
			'selector'            => '#music_zone_pro_instagram_section h2.section-title',
			'settings'            => 'music_zone_pro_theme_options[instagram_section_title]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'music_zone_pro_instagram_section_title_partial',
		) 
	);
}

// Subscribe button text setting
$wp_customize->add_setting('music_zone_pro_theme_options[instagram_section_shortcode]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['instagram_section_shortcode'],
    )
);

$wp_customize->add_control('music_zone_pro_theme_options[instagram_section_shortcode]',
    array(
        'section'		    => 'music_zone_pro_instagram_section',
        'label'			    => esc_html__( 'Shortcode:', 'music-zone-pro' ),
        'active_callback'   => 'music_zone_pro_is_instagram_section_enable',
        'type'              =>'textarea'

    )
);
    
