<?php
/**
 * Latest Posts Section options
 *
 * @package Theme Palace
 * @subpackage Music Zone Pro
 * @since Music Zone Pro 1.0.0
 */

// Add Latest Posts section
$wp_customize->add_section( 'music_zone_pro_latest_posts_section', array(
	'title'             => esc_html__( 'Latest Posts','music-zone-pro' ),
	'description'       => esc_html__( 'Latest Posts Section options.', 'music-zone-pro' ),
	'panel'             => 'music_zone_pro_front_page_panel',
	'active_callback'   => function( $control ) {
		return (
			music_zone_pro_is_default_layout( $control )
			||
			music_zone_pro_is_second_layout( $control )
			||
			music_zone_pro_is_third_layout( $control )
			||
			music_zone_pro_is_fourth_layout( $control )
		);
	},
) );

// Latest Posts content enable control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[latest_posts_section_enable]', array(
	'default'			=> 	$options['latest_posts_section_enable'],
	'sanitize_callback' => 'music_zone_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Music_Zone_Pro_Switch_Control( $wp_customize, 'music_zone_pro_theme_options[latest_posts_section_enable]', array(
	'label'             => esc_html__( 'Latest Posts Section Enable', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_latest_posts_section',
	'on_off_label' 		=> music_zone_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[latest_posts_section_enable]', array(
		'selector'      => '.latest-posts-section .tooltiptext',
		'settings'      => 'music_zone_pro_theme_options[latest_posts_section_enable]',
    ) );
}


// latest posts title setting and control
$wp_customize->add_setting( 'music_zone_pro_theme_options[latest_posts_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['latest_posts_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[latest_posts_title]', array(
	'label'           	=> esc_html__( 'Title', 'music-zone-pro' ),
	'section'        	=> 'music_zone_pro_latest_posts_section',
	'active_callback' 	=> 'music_zone_pro_is_latest_posts_section_enable',
	'type'				=> 'text',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[latest_posts_title]', array(
		'selector'      => '#music_zone_pro_latest_posts_section .section-header .section-title',
		'settings'      => 'music_zone_pro_theme_options[latest_posts_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'music_zone_pro_latest_posts_title_partial',
    ) );
}


// latest posts subtitle setting and control
$wp_customize->add_setting( 'music_zone_pro_theme_options[latest_posts_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['latest_posts_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[latest_posts_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'music-zone-pro' ),
	'section'        	=> 'music_zone_pro_latest_posts_section',
	'active_callback' 	=> 'music_zone_pro_is_latest_posts_section_enable',
	'type'				=> 'text',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[latest_posts_subtitle]', array(
		'selector'      => '#music_zone_pro_latest_posts_section .section-header .section-subtitle',
		'settings'      => 'music_zone_pro_theme_options[latest_posts_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'music_zone_pro_latest_posts_subtitle_partial',
    ) );
}


// Latest Posts content type control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[latest_posts_content_type]', array(
	'default'          	=> $options['latest_posts_content_type'],
	'sanitize_callback' => 'music_zone_pro_sanitize_select',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[latest_posts_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_latest_posts_section',
	'type'				=> 'select',
	'active_callback' 	=> 'music_zone_pro_is_latest_posts_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'music-zone-pro' ),
		'post' 		=> esc_html__( 'Post', 'music-zone-pro' ),
		'category' 	=> esc_html__( 'Category', 'music-zone-pro' ),
		'recent' 	=> esc_html__( 'Recent', 'music-zone-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[latest_posts_count]', array(
	'default'          	=> $options['latest_posts_count'],
	'sanitize_callback' => 'music_zone_pro_sanitize_number_range',
	'validate_callback' => 'music_zone_pro_validate_latest_posts_count',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[latest_posts_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'music-zone-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 8. Please input the valid number and save. Then refresh the page to see the change.', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_latest_posts_section',
	'active_callback'   => 'music_zone_pro_is_latest_posts_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 8,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['latest_posts_count']; $i++ ) :
	// Latest Posts pages drop down chooser control and setting
	$wp_customize->add_setting( 'music_zone_pro_theme_options[latest_posts_content_page_' . $i . ']', array(
		'sanitize_callback' => 'music_zone_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Music_Zone_Pro_Dropdown_Chooser( $wp_customize, 'music_zone_pro_theme_options[latest_posts_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'music-zone-pro' ), $i ),
		'section'           => 'music_zone_pro_latest_posts_section',
		'choices'			=> music_zone_pro_page_choices(),
		'active_callback'	=> 'music_zone_pro_is_latest_posts_section_content_page_enable',
	) ) );

	// latest posts drop down chooser control and setting
	$wp_customize->add_setting( 'music_zone_pro_theme_options[latest_posts_content_post_' . $i . ']', array(
		'sanitize_callback' => 'music_zone_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Music_Zone_Pro_Dropdown_Chooser( $wp_customize, 'music_zone_pro_theme_options[latest_posts_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'music-zone-pro' ), $i ),
		'section'           => 'music_zone_pro_latest_posts_section',
		'choices'			=> music_zone_pro_post_choices(),
		'active_callback'	=> 'music_zone_pro_is_latest_posts_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'music_zone_pro_theme_options[latest_posts_content_category]', array(
	'sanitize_callback' => 'music_zone_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Music_Zone_Pro_Dropdown_Taxonomies_Control( $wp_customize,'music_zone_pro_theme_options[latest_posts_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'music-zone-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_latest_posts_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'music_zone_pro_is_latest_posts_section_content_category_enable'
) ) );

// Add dropdown categories setting and control.
$wp_customize->add_setting( 'music_zone_pro_theme_options[latest_posts_category_exclude]', array(
	'sanitize_callback' => 'music_zone_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Music_Zone_Pro_Dropdown_Category_Control( $wp_customize,'music_zone_pro_theme_options[latest_posts_category_exclude]', array(
	'label'             => esc_html__( 'Select Excluding Categories', 'music-zone-pro' ),
	'description'      	=> esc_html__( 'Note: Select categories to exclude. Press Shift key select multilple categories.', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_latest_posts_section',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'music_zone_pro_is_latest_posts_section_content_recent_enable'
) ) );
