<?php
/**
 * Partners Section options
 *
 * @package Theme Palace
 * @sub_package Music Zone Pro
 * @since Music Zone Pro 1.0.0
 */

// Add Partners section
$wp_customize->add_section( 'music_zone_pro_partners_section', array(
	'title'             => esc_html__( 'Our Partners','music-zone-pro' ),
	'description'       => esc_html__( 'Partners Section options.', 'music-zone-pro' ),
	'panel'             => 'music_zone_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return ( 
        	music_zone_pro_is_second_layout( $control )
        	||
        	music_zone_pro_is_second_layout( $control )
        	||
        	music_zone_pro_is_fourth_layout( $control )
        );
    },
) );

// Partners content enable control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[partners_section_enable]', array(
	'default'			=> 	$options['partners_section_enable'],
	'sanitize_callback' => 'music_zone_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Music_Zone_Pro_Switch_Control( $wp_customize, 'music_zone_pro_theme_options[partners_section_enable]', array(
	'label'             => esc_html__( 'Partners Section Enable', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_partners_section',
	'on_off_label' 		=> music_zone_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[partners_section_enable]', array(
		'selector'            => '#partners-section .tooltiptext',
		'settings'            => 'music_zone_pro_theme_options[partners_section_enable]',
    ) );
}

// Latest Posts btn label setting and control
$wp_customize->add_setting( 'music_zone_pro_theme_options[partners_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['partners_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[partners_subtitle]', array(
	'label'           	=> esc_html__( 'Section Sub Title', 'music-zone-pro' ),
	'section'        	=> 'music_zone_pro_partners_section',
	'active_callback' 	=> 'music_zone_pro_is_partners_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[partners_subtitle]', array(
		'selector'            => '#music_zone_pro_partners_section p.section-subtitle',
		'settings'            => 'music_zone_pro_theme_options[partners_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'music_zone_pro_partners_subtitle_partial',
    ) );
}

// Latest Posts btn label setting and control
$wp_customize->add_setting( 'music_zone_pro_theme_options[partners_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['partners_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[partners_title]', array(
	'label'           	=> esc_html__( 'Section Title', 'music-zone-pro' ),
	'section'        	=> 'music_zone_pro_partners_section',
	'active_callback' 	=> 'music_zone_pro_is_partners_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[partners_title]', array(
		'selector'            => '#music_zone_pro_partners_section h2.section-title',
		'settings'            => 'music_zone_pro_theme_options[partners_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'music_zone_pro_partners_title_partial',
    ) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[partners_count]', array(
	'default'          	=> $options['partners_count'],
	'sanitize_callback' => 'music_zone_pro_sanitize_number_range',
	'validate_callback' => 'music_zone_pro_validate_partners_count',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[partners_count]', array(
	'label'             => esc_html__( 'Number of Partners', 'music-zone-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 20. Please input the valid number and save. Then refresh the page to see the change.', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_partners_section',
	'active_callback'   => 'music_zone_pro_is_partners_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 20,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['partners_count']; $i++ ) :

	// Partners image setting and control.
	$wp_customize->add_setting( 'music_zone_pro_theme_options[partners_image_' . $i . ']', array(
		'sanitize_callback' => 'music_zone_pro_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'music_zone_pro_theme_options[partners_image_' . $i . ']',
			array(
			'label'       		=> sprintf( esc_html__( 'Image %d', 'music-zone-pro' ), $i),
			'section'     		=> 'music_zone_pro_partners_section',
			'active_callback'	=> 'music_zone_pro_is_partners_section_enable',
	) ) );

	// Partners url setting and control
	$wp_customize->add_setting( 'music_zone_pro_theme_options[partners_url_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'music_zone_pro_theme_options[partners_url_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Partners Url %d', 'music-zone-pro' ), $i),
		'section'        	=> 'music_zone_pro_partners_section',
		'active_callback' 	=> 'music_zone_pro_is_partners_section_enable',
		'type'				=> 'url',
	) );

endfor;