<?php
/**
 * Popular Products Section options
 *
 * @package Theme Palace
 * @subpackage Music Zone Pro
 * @since Music Zone Pro 1.0.0
 */
if ( !class_exists('WooCommerce') ) {
    return;
}

// Add popular_products section
$wp_customize->add_section( 'music_zone_pro_popular_products_section', array(
    'title'             => esc_html__( 'Popular Products','music-zone-pro' ),
    'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'music-zone-pro' ),
    'panel'             => 'music_zone_pro_front_page_panel',
    'active_callback'   => function( $control ) {
        return ( 
            music_zone_pro_is_fourth_layout( $control )
        );
    },
) );

// popular_products content enable control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[popular_products_section_enable]', array(
    'default'           =>  $options['popular_products_section_enable'],
    'sanitize_callback' => 'music_zone_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Music_Zone_Pro_Switch_Control( $wp_customize, 'music_zone_pro_theme_options[popular_products_section_enable]', array(
    'label'             => esc_html__( 'Popular product Section Enable', 'music-zone-pro' ),
    'section'           => 'music_zone_pro_popular_products_section',
    'on_off_label'      => music_zone_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[popular_products_section_enable]', array(
        'selector'            => '#music_zone_pro_popular_products_section .tooltiptext',
        'settings'            => 'music_zone_pro_theme_options[popular_products_section_enable]',
    ) );
}

// popular_products title setting and control
$wp_customize->add_setting( 'music_zone_pro_theme_options[popular_products_sub_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['popular_products_sub_title'],       
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[popular_products_sub_title]', array(
    'label'             => esc_html__( 'Sub Title', 'music-zone-pro' ),
    'section'           => 'music_zone_pro_popular_products_section',
    'active_callback'   => 'music_zone_pro_is_popular_products_section_enable',
    'type'              => 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[popular_products_sub_title]', array(
        'selector'            => '#music_zone_pro_popular_products_section p.section-subtitle',
        'settings'            => 'music_zone_pro_theme_options[popular_products_sub_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'music_zone_pro_popular_products_section_sub_title_partial',
    ) );
}

// popular_products title setting and control
$wp_customize->add_setting( 'music_zone_pro_theme_options[popular_products_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['popular_products_title'],
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[popular_products_title]', array(
    'label'             => esc_html__( 'Title', 'music-zone-pro' ),
    'section'           => 'music_zone_pro_popular_products_section',
    'active_callback'   => 'music_zone_pro_is_popular_products_section_enable',
    'type'              => 'text',
) );
// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[popular_products_title]', array(
        'selector'            => '#music_zone_pro_popular_products_section h2.section-title',
        'settings'            => 'music_zone_pro_theme_options[popular_products_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'music_zone_pro_popular_products_section_title_partial',
    ) );
}

$wp_customize->add_setting( 'music_zone_pro_theme_options[popular_products_count]', array(
    'default'           => $options['popular_products_count'],
    'sanitize_callback' => 'music_zone_pro_sanitize_number_range',
    'validate_callback' => 'music_zone_pro_validate_popular_products_count',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[popular_products_count]', array(
    'label'             => esc_html__( 'Number of Products', 'music-zone-pro' ),
    'description'       => esc_html__( 'Note: Min 1 & Max 50. Please input the valid number and save. Then refresh the page to see the change.', 'music-zone-pro' ),
    'section'           => 'music_zone_pro_popular_products_section',
    'active_callback'   => 'music_zone_pro_is_popular_products_section_enable',
    'type'              => 'number',
    'input_attrs'       => array(
        'min'   => 1,
        'max'   => 50,
        'style' => 'width: 100px;'
        ),
) );

$wp_customize->add_setting( 'music_zone_pro_theme_options[popular_products_content_type]', array(
    'default'           => $options['popular_products_content_type'],
    'sanitize_callback' => 'music_zone_pro_sanitize_select',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[popular_products_content_type]', array(
    'label'             => esc_html__( 'Content Type', 'music-zone-pro' ),
    'section'           => 'music_zone_pro_popular_products_section',
    'type'              => 'select',
    'active_callback'   => 'music_zone_pro_is_popular_products_section_enable',
    'choices'           => array(
        'product'           => esc_html__( 'Product', 'music-zone-pro' ),
        'product-category'  => esc_html__( 'Product Category', 'music-zone-pro' ),
        ),
) );

for( $i = 1 ; $i <= $options['popular_products_count']; $i++ ){

    $wp_customize->add_setting( 'music_zone_pro_theme_options[popular_products_content_product_' . $i . ']', array(
        'sanitize_callback' => 'music_zone_pro_sanitize_page',
    ) );

    $wp_customize->add_control( new Music_Zone_Pro_Dropdown_Chooser( $wp_customize, 'music_zone_pro_theme_options[popular_products_content_product_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Product %d', 'music-zone-pro' ), $i ),
        'section'           => 'music_zone_pro_popular_products_section',
        'choices'           => music_zone_pro_product_choices(),
        'active_callback'   => 'music_zone_pro_is_popular_products_section_content_product_enable',
    ) ) );
}

$wp_customize->add_setting(  'music_zone_pro_theme_options[popular_products_content_product_category]', array(
        'sanitize_callback' => 'absint',
    ) ) ;

$wp_customize->add_control( new Music_Zone_Pro_Dropdown_Taxonomies_Control( $wp_customize,'music_zone_pro_theme_options[popular_products_content_product_category]', array(
    'label'             => esc_html__( 'Select Product Categories', 'music-zone-pro' ),
    'description'       => esc_html__( 'Note: Press CTRL and select multiple category. Latest four posts will be shown from each selected category', 'music-zone-pro' ),
    'section'           => 'music_zone_pro_popular_products_section',
    'taxonomy'          => 'product_cat',
    'type'              => 'dropdown-taxonomies',
    'active_callback'   => 'music_zone_pro_is_popular_products_section_content_product_category_enable',
) ) );
