<?php
/**
 * Recent Posts Section options
 *
 * @package Theme Palace
 * @subpackage Music Zone Pro
 * @since Music Zone Pro 1.0.0
 */

// Add Recent Posts section
$wp_customize->add_section( 'music_zone_pro_recent_posts_section', array(
	'title'             => esc_html__( 'Recent Posts','music-zone-pro' ),
	'description'       => esc_html__( 'Recent Posts Section options.', 'music-zone-pro' ),
	'panel'             => 'music_zone_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return ( 
            music_zone_pro_is_third_layout( $control )
        );
    },
) );

// Recent Posts content enable control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[recent_posts_section_enable]', array(
	'default'			=> 	$options['recent_posts_section_enable'],
	'sanitize_callback' => 'music_zone_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Music_Zone_Pro_Switch_Control( $wp_customize, 'music_zone_pro_theme_options[recent_posts_section_enable]', array(
	'label'             => esc_html__( 'Recent Posts Section Enable', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_recent_posts_section',
	'on_off_label' 		=> music_zone_pro_switch_options(),
) ) );


// recent_posts sub_title setting and control
$wp_customize->add_setting( 'music_zone_pro_theme_options[recent_posts_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['recent_posts_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[recent_posts_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'music-zone-pro' ),
	'section'        	=> 'music_zone_pro_recent_posts_section',
	'active_callback' 	=> 'music_zone_pro_is_recent_posts_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[recent_posts_sub_title]', array(
		'selector'            => '#music_zone_pro_recent_posts_section p.section-subtitle',
		'settings'            => 'music_zone_pro_theme_options[recent_posts_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'music_zone_pro_recent_posts_sub_title_partial',
    ) );
}

// recent_posts title setting and control
$wp_customize->add_setting( 'music_zone_pro_theme_options[recent_posts_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['recent_posts_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[recent_posts_title]', array(
	'label'           	=> esc_html__( 'Title', 'music-zone-pro' ),
	'section'        	=> 'music_zone_pro_recent_posts_section',
	'active_callback' 	=> 'music_zone_pro_is_recent_posts_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[recent_posts_title]', array(
		'selector'            => '#music_zone_pro_recent_posts_section h2.section-title',
		'settings'            => 'music_zone_pro_theme_options[recent_posts_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'music_zone_pro_recent_posts_title_partial',
    ) );
}

// Recent Posts content type control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[recent_posts_column_layout]', array(
	'default'          	=> $options['recent_posts_column_layout'],
	'sanitize_callback' => 'music_zone_pro_sanitize_select',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[recent_posts_column_layout]', array(
	'label'             => esc_html__( 'Column Layout', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_recent_posts_section',
	'type'				=> 'select',
	'active_callback' 	=> 'music_zone_pro_is_recent_posts_section_enable',
	'choices'			=> array(
            'col-3'      => esc_html__( 'Three Column', 'music-zone-pro' ),
            'col-4'      => esc_html__( 'Four Column', 'music-zone-pro' ),
        )
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[recent_posts_count]', array(
	'default'          	=> $options['recent_posts_count'],
	'sanitize_callback' => 'music_zone_pro_sanitize_number_range',
	'validate_callback' => 'music_zone_pro_validate_recent_posts_count',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[recent_posts_count]', array(
	'label'             => esc_html__( 'Number of posts', 'music-zone-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 50. Please input the valid number and save. Then refresh the page to see the change.', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_recent_posts_section',
	'active_callback'   => 'music_zone_pro_is_recent_posts_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 50,
		'style' => 'width: 100px;'
		),
) );

// long Excerpt length setting and control.
$wp_customize->add_setting( 'music_zone_pro_theme_options[recent_posts_excerpt_length]', array(
	'sanitize_callback' => 'music_zone_pro_sanitize_number_range',
	'validate_callback' => 'music_zone_pro_validate_long_excerpt',
	'default'			=> $options['recent_posts_excerpt_length'],
	) );

$wp_customize->add_control( 'music_zone_pro_theme_options[recent_posts_excerpt_length]', array(
	'label'       		=> esc_html__( 'Recent Posts Excerpt Length', 'music-zone-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in recent_posts posts.', 'music-zone-pro' ),
	'section'     		=> 'music_zone_pro_recent_posts_section',
	'active_callback' 	=> 'music_zone_pro_is_recent_posts_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
		),
	) );

// Recent Posts content type control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[recent_posts_content_type]', array(
	'default'          	=> $options['recent_posts_content_type'],
	'sanitize_callback' => 'music_zone_pro_sanitize_select',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[recent_posts_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_recent_posts_section',
	'type'				=> 'select',
	'active_callback' 	=> 'music_zone_pro_is_recent_posts_section_enable',
	'choices'			=> array(
            'page'      => esc_html__( 'Page', 'music-zone-pro' ),
            'post'      => esc_html__( 'Post', 'music-zone-pro' ),
            'category'  => esc_html__( 'Category', 'music-zone-pro' ),
        )
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'music_zone_pro_theme_options[recent_posts_content_category]', array(
	'sanitize_callback' => 'music_zone_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Music_Zone_Pro_Dropdown_Taxonomies_Control( $wp_customize,'music_zone_pro_theme_options[recent_posts_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'music-zone-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_recent_posts_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'music_zone_pro_is_recent_posts_section_content_category_enable'
) ) );

for ( $i = 1; $i <= $options['recent_posts_count']; $i++ ) :

	// recent_posts pages drop down chooser control and setting
	$wp_customize->add_setting( 'music_zone_pro_theme_options[recent_posts_content_page_' . $i . ']', array(
		'sanitize_callback' => 'music_zone_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Music_Zone_Pro_Dropdown_Chooser( $wp_customize, 'music_zone_pro_theme_options[recent_posts_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'music-zone-pro' ), $i ),
		'section'           => 'music_zone_pro_recent_posts_section',
		'choices'			=> music_zone_pro_page_choices(),
		'active_callback'	=> 'music_zone_pro_is_recent_posts_section_content_page_enable',
	) ) );

	// recent_posts posts drop down chooser control and setting
	$wp_customize->add_setting( 'music_zone_pro_theme_options[recent_posts_content_post_' . $i . ']', array(
		'sanitize_callback' => 'music_zone_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Music_Zone_Pro_Dropdown_Chooser( $wp_customize, 'music_zone_pro_theme_options[recent_posts_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'music-zone-pro' ), $i ),
		'section'           => 'music_zone_pro_recent_posts_section',
		'choices'			=> music_zone_pro_post_choices(),
		'active_callback'	=> 'music_zone_pro_is_recent_posts_section_content_post_enable',
	) ) );

endfor;