<?php
/**
 * Product Section options
 *
 * @package Theme Palace
 * @subpackage Music Zone Pro
 * @since Music Zone Pro 1.0.0
 */

// Add Product section
$wp_customize->add_section( 'music_zone_pro_recent_product_section', array(
	'title'             => esc_html__( 'Recent Product','music-zone-pro' ),
	'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'music-zone-pro' ),
	'panel'             => 'music_zone_pro_front_page_panel',
	'active_callback'   => function( $control ) {
		return (
			music_zone_pro_is_default_layout( $control )
			||
        	music_zone_pro_is_third_layout( $control )
        	||
        	music_zone_pro_is_fourth_layout( $control )
		);
	},
) );

// Product content enable control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[recent_product_section_enable]', array(
	'default'			=> 	$options['recent_product_section_enable'],
	'sanitize_callback' => 'music_zone_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Music_Zone_Pro_Switch_Control( $wp_customize, 'music_zone_pro_theme_options[recent_product_section_enable]', array(
	'label'             => esc_html__( 'Product Section Enable', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_recent_product_section',
	'on_off_label' 		=> music_zone_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[recent_product_section_enable]', array(
		'selector'            => '#music_zone_pro_recent_product_section .tooltiptext',
		'settings'            => 'music_zone_pro_theme_options[recent_product_section_enable]',
    ) );
}


// product title setting and control
$wp_customize->add_setting( 'music_zone_pro_theme_options[recent_product_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['recent_product_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[recent_product_title]', array(
	'label'           	=> esc_html__( 'Title', 'music-zone-pro' ),
	'section'        	=> 'music_zone_pro_recent_product_section',
	'active_callback' 	=> 'music_zone_pro_is_recent_product_section_enable',
	'type'				=> 'text',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[recent_product_title]', array(
		'selector'            => '#music_zone_pro_recent_product_section .section-title',
		'settings'            => 'music_zone_pro_theme_options[recent_product_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'music_zone_pro_recent_product_title_partial',
    ) );
}


// product subtitle setting and control
$wp_customize->add_setting( 'music_zone_pro_theme_options[recent_product_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['recent_product_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[recent_product_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'music-zone-pro' ),
	'section'        	=> 'music_zone_pro_recent_product_section',
	'active_callback' 	=> 'music_zone_pro_is_recent_product_section_enable',
	'type'				=> 'text',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[recent_product_subtitle]', array(
		'selector'            => '#music_zone_pro_recent_product_section .section-subtitle',
		'settings'            => 'music_zone_pro_theme_options[recent_product_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'music_zone_pro_recent_product_subtitle_partial',
    ) );
}


// Product content type control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[recent_product_content_type]', array(
	'default'          	=> $options['recent_product_content_type'],
	'sanitize_callback' => 'music_zone_pro_sanitize_select',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[recent_product_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_recent_product_section',
	'type'				=> 'select',
	'active_callback' 	=> 'music_zone_pro_is_recent_product_section_enable',
	'choices'			=> music_zone_pro_product_content_type(),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[recent_product_count]', array(
	'default'          	=> $options['recent_product_count'],
	'sanitize_callback' => 'music_zone_pro_sanitize_number_range',
	'validate_callback' => 'music_zone_pro_validate_recent_product_count',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[recent_product_count]', array(
	'label'             => esc_html__( 'Number of Product', 'music-zone-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_recent_product_section',
	'active_callback'   => 'music_zone_pro_is_recent_product_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['recent_product_count']; $i++ ) :

	// product posts drop down chooser control and setting
	$wp_customize->add_setting( 'music_zone_pro_theme_options[recent_product_content_product_' . $i . ']', array(
		'sanitize_callback' => 'music_zone_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Music_Zone_Pro_Dropdown_Chooser( $wp_customize, 'music_zone_pro_theme_options[recent_product_content_product_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Product %d', 'music-zone-pro' ), $i ),
		'section'           => 'music_zone_pro_recent_product_section',
		'choices'			=> music_zone_pro_product_choices(),
		'active_callback'	=> 'music_zone_pro_is_recent_product_section_content_product_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'music_zone_pro_theme_options[recent_product_content_product_category]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Music_Zone_Pro_Dropdown_Taxonomies_Control( $wp_customize,'music_zone_pro_theme_options[recent_product_content_product_category]', array(
	'label'             => esc_html__( 'Select Product Category', 'music-zone-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_recent_product_section',
	'taxonomy'			=> 'product_cat',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'music_zone_pro_is_recent_product_section_content_product_category_enable'
) ) );
