<?php
/**
 * Service Section options
 *
 * @package Theme Palace
 * @subpackage  Music Zone Pro
 * @since  Music Zone Pro 1.0.0
 */

// Add Service section
$wp_customize->add_section( 'music_zone_pro_service_section', 
	array(
		'title'             => esc_html__( 'Services','music-zone-pro' ),
		'description'       => esc_html__( 'Services Section options.', 'music-zone-pro' ),
		'panel'             => 'music_zone_pro_front_page_panel',
		'active_callback'   => function( $control ) {
			return (
				music_zone_pro_is_default_layout( $control )
				||
				music_zone_pro_is_second_layout( $control )
			);
		},
	) 
);

// Service content enable control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[service_section_enable]', 
	array(
		'default'			=> 	$options['service_section_enable'],
		'sanitize_callback' => 'music_zone_pro_sanitize_switch_control',
	) 
);

$wp_customize->add_control( new  music_zone_Pro_Switch_Control( $wp_customize,
	'music_zone_pro_theme_options[service_section_enable]', 
		array(
			'label'             => esc_html__( 'Service Section Enable', 'music-zone-pro' ),
			'section'           => 'music_zone_pro_service_section',
			'on_off_label' 		=> music_zone_pro_switch_options(),
		) 
	)
);

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[service_section_enable]', array(
		'selector' => '.service-section .tooltiptext',
		'settings' => 'music_zone_pro_theme_options[service_section_enable]',
    ) );
}

$wp_customize->add_setting( 'music_zone_pro_theme_options[service_section_sub_title]',
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'transport'         => 'postMessage',
		'default'           => $options['service_section_sub_title'],
	)

);

$wp_customize->add_control( 'music_zone_pro_theme_options[service_section_sub_title]',
	array(
		'label'           => esc_html__( 'Section Sub Title', 'music-zone-pro' ),
		'section'         => 'music_zone_pro_service_section',
		'type'            => 'text',
		'active_callback' => 'music_zone_pro_is_service_section_enable',
	)

);

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[service_section_sub_title]', array(
		'selector'            => '#music_zone_pro_service_section p.section-subtitle',
		'settings'            => 'music_zone_pro_theme_options[service_section_sub_title]',
		'fallback_refresh'    => true,
		'container_inclusive' => false,
		'validate_callback'   => 'music_zone_pro_service_section_sub_title_partial',
    ) );
}


$wp_customize->add_setting( 'music_zone_pro_theme_options[service_section_title]',
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'transport'         => 'postMessage',
		'default'           => $options['service_section_title'],
	)
);

$wp_customize->add_control( 'music_zone_pro_theme_options[service_section_title]',
	array(
		'label'           => esc_html__( 'Section Title', 'music-zone-pro' ),
		'section'         => 'music_zone_pro_service_section',
		'type'            => 'text',
		'active_callback' => 'music_zone_pro_is_service_section_enable',
	)
);

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[service_section_title]', array(
		'selector'            => '#music_zone_pro_service_section h2.section-title',
		'settings'            => 'music_zone_pro_theme_options[service_section_title]',
		'fallback_refresh'    => true,
		'container_inclusive' => false,
		'validate_callback'   => 'music_zone_pro_service_section_title_partial',
    ) );
}

$wp_customize->add_setting( 'music_zone_pro_theme_options[service_content_type]',
	array(
		'sanitize_callback' => 'music_zone_pro_sanitize_select',
		'default'           => $options['service_content_type'],
	)

);

$wp_customize->add_control( 'music_zone_pro_theme_options[service_content_type]',
	array(
		'label'           => esc_html__( 'Content Type', 'music-zone-pro' ),
		'section'         => 'music_zone_pro_service_section',
		'type'            => 'select',
		'active_callback' => 'music_zone_pro_is_service_section_enable',
		'choices'		=> array( 
			'page' 		=> esc_html__( 'Page', 'music-zone-pro' ),
			'post' 		=> esc_html__( 'Post', 'music-zone-pro' ),
			'category' 	=> esc_html__( 'Category', 'music-zone-pro' ),
		),
	) 
);


// Services post number control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[service_posts_count]', 
	array(
		'default'          	=> $options['service_posts_count'],
		'sanitize_callback' => 'music_zone_pro_sanitize_number_range',
		'validate_callback' => 'music_zone_pro_validate_service_posts_count',
	)
);

$wp_customize->add_control( 'music_zone_pro_theme_options[service_posts_count]', 
	array(
		'label'             => esc_html__( 'Number of Posts', 'music-zone-pro' ),
		'description'       => esc_html__( 'Note: Min 3 & Max 6. Please input the valid number and save. Then refresh the page to see the change.', 'music-zone-pro' ),
		'section'           => 'music_zone_pro_service_section',
		'type'				=> 'number',
		'active_callback' 	=> 'music_zone_pro_is_service_section_enable',
		'input_attrs'		=> array(
			'min'	=> 3,
			'max'	=> 6,
			'style' => 'width: 100px;'
		),
	) 
);

// long Excerpt length setting and control.
$wp_customize->add_setting( 'music_zone_pro_theme_options[service_excerpt_length]', array(
	'sanitize_callback' => 'music_zone_pro_sanitize_number_range',
	'validate_callback' => 'music_zone_pro_validate_long_excerpt',
	'default'			=> $options['service_excerpt_length'],
	) );

$wp_customize->add_control( 'music_zone_pro_theme_options[service_excerpt_length]', array(
	'label'       		=> esc_html__( 'Service Excerpt Length', 'music-zone-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in service posts.', 'music-zone-pro' ),
	'section'     		=> 'music_zone_pro_service_section',
	'active_callback' 	=> 'music_zone_pro_is_service_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
		),
	) );

for($i = 1; $i <= $options['service_posts_count']; $i ++):

	// service note control and setting
	$wp_customize->add_setting( 'music_zone_pro_theme_options[service_content_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
		) );

$wp_customize->add_control( new Music_Zone_Pro_Icon_Picker( $wp_customize, 'music_zone_pro_theme_options[service_content_icon_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Icon %d', 'music-zone-pro' ), $i ),
	'section'           => 'music_zone_pro_service_section',
	'active_callback'	=> 'music_zone_pro_is_service_section_enable',
	) ) );

    // service pages drop down chooser control and setting
	$wp_customize->add_setting( 'music_zone_pro_theme_options[service_content_page_'.$i.']',
		array(
			'sanitize_callback' => 'music_zone_pro_sanitize_page',
		) 
	);

	$wp_customize->add_control( new  music_zone_Pro_Dropdown_Chooser( $wp_customize,
		'music_zone_pro_theme_options[service_content_page_'.$i.']',
			array(
				'label'             => sprintf(esc_html__( 'Select Page : %d', 'music-zone-pro'), $i ),
				'section'           => 'music_zone_pro_service_section',
				'choices'			=> music_zone_pro_page_choices(),
				'active_callback'	=> 'music_zone_pro_is_service_section_content_page_enable',
			) 
		)
	);

	// service posts drop down chooser control and setting
	$wp_customize->add_setting( 'music_zone_pro_theme_options[service_content_post_'.$i.']', 
		array(
			'sanitize_callback' => 'music_zone_pro_sanitize_page',
		) 
	);

	$wp_customize->add_control( new  music_zone_Pro_Dropdown_Chooser( $wp_customize,
		'music_zone_pro_theme_options[service_content_post_'.$i.']', 
			array(
				'label'             => sprintf(esc_html__( 'Select Post : %d', 'music-zone-pro'), $i ),
				'section'           => 'music_zone_pro_service_section',
				'choices'			=> music_zone_pro_post_choices(),
				'active_callback'	=> 'music_zone_pro_is_service_section_content_post_enable',
			)
		)
	);

	  // Medistore_Pro_Customize_Horizontal_Line
    $wp_customize->add_setting('music_zone_pro_theme_options[service_separator'. $i .']',
		array(
			'sanitize_callback'      => 'music_zone_pro_sanitize_html',
		)
	);

    $wp_customize->add_control(new  Music_Zone_Pro_Customize_Horizontal_Line($wp_customize,
		'music_zone_pro_theme_options[service_separator'. $i .']',
			array(
				'active_callback'       => 'music_zone_pro_is_service_section_hr_enable',
				'type'                  =>'hr',
				'section'               =>'music_zone_pro_service_section',
			)
		)
	);

endfor;

// service category drop down chooser control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[service_category]', 
	array(
		'sanitize_callback' => 'music_zone_pro_sanitize_single_category',
	)
);

$wp_customize->add_control( new  Music_Zone_Pro_Dropdown_Taxonomies_Control( $wp_customize,
	'music_zone_pro_theme_options[service_category]',
		array(
			'label'             => esc_html__( 'Select Categories', 'music-zone-pro' ),
			'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'music-zone-pro' ),
			'type'           	=> 'dropdown-taxonomies',
			'section'           => 'music_zone_pro_service_section',
			'active_callback'	=> 'music_zone_pro_is_service_section_content_category_enable',
		) 
	)
);