<?php
/**
 * team Section options
 *
 * @package Theme Palace
 * @subpackage Music Zone Pro
 * @since Music Zone Pro 1.0.0
 */

// Add team section
$wp_customize->add_section( 'music_zone_pro_team_section', array(
	'title'             =>	esc_html__( 'Team', 'music-zone-pro' ),
	'description'       => esc_html__( 'Team Section options.', 'music-zone-pro' ),
	'panel'             => 'music_zone_pro_front_page_panel',
	'active_callback'   => function( $control ) {
		return (
			music_zone_pro_is_default_layout( $control )
			||
			music_zone_pro_is_second_layout( $control )
		);
	},
) );

// team content enable control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[team_section_enable]', array(
	'default'			=> 	$options['team_section_enable'],
	'sanitize_callback' => 'music_zone_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Music_Zone_Pro_Switch_Control( $wp_customize, 'music_zone_pro_theme_options[team_section_enable]', array(
	'label'             => esc_html__( 'Team Section Enable', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_team_section',
	'on_off_label' 		=> music_zone_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[team_section_enable]', array(
		'selector'            => '.team-section .tooltiptext',
		'settings'            => 'music_zone_pro_theme_options[team_section_enable]',
    ) );
}


// team title setting and control
$wp_customize->add_setting( 'music_zone_pro_theme_options[team_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['team_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[team_title]', array(
	'label'           	=> esc_html__( 'Title', 'music-zone-pro' ),
	'section'        	=> 'music_zone_pro_team_section',
	'active_callback' 	=> 'music_zone_pro_is_team_section_enable',
	'type'				=> 'text',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[team_title]', array(
		'selector'            => '#music_zone_pro_team_section .section-header .section-title',
		'settings'            => 'music_zone_pro_theme_options[team_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'music_zone_pro_team_title_partial',
    ) );
}

// team sub title setting and control
$wp_customize->add_setting( 'music_zone_pro_theme_options[team_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['team_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[team_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'music-zone-pro' ),
	'section'        	=> 'music_zone_pro_team_section',
	'active_callback' 	=> 'music_zone_pro_is_team_section_enable',
	'type'				=> 'text',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[team_sub_title]', array(
		'selector'            => '#music_zone_pro_team_section .section-header .section-subtitle',
		'settings'            => 'music_zone_pro_theme_options[team_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'music_zone_pro_team_sub_title_partial',
    ) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[team_count]', array(
	'default'          	=> $options['team_count'],
	'sanitize_callback' => 'music_zone_pro_sanitize_number_range',
	'validate_callback' => 'music_zone_pro_validate_team_count',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[team_count]', array(
	'label'             => esc_html__( 'Number of Team', 'music-zone-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_team_section',
	'active_callback'   => 'music_zone_pro_is_team_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );



// team content type control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[team_content_type]', array(
	'default'          	=> $options['team_content_type'],
	'sanitize_callback' => 'music_zone_pro_sanitize_select',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[team_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_team_section',
	'type'				=> 'select',
	'active_callback' 	=> 'music_zone_pro_is_team_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'music-zone-pro' ),
		'post' 		=> esc_html__( 'Post', 'music-zone-pro' ),
		'category' 	=> esc_html__( 'Category', 'music-zone-pro' ),
	),
) );

for ( $i = 1; $i <= $options['team_count']; $i++ ) :
	// team pages drop down chooser control and setting
	$wp_customize->add_setting( 'music_zone_pro_theme_options[team_content_page_' . $i . ']', array(
		'sanitize_callback' => 'music_zone_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Music_Zone_Pro_Dropdown_Chooser( $wp_customize, 'music_zone_pro_theme_options[team_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'music-zone-pro' ), $i ),
		'section'           => 'music_zone_pro_team_section',
		'choices'			=> music_zone_pro_page_choices(),
		'active_callback'	=> 'music_zone_pro_is_team_section_content_page_enable',
	) ) );

	// team posts drop down chooser control and setting
	$wp_customize->add_setting( 'music_zone_pro_theme_options[team_content_post_' . $i . ']', array(
		'sanitize_callback' => 'music_zone_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Music_Zone_Pro_Dropdown_Chooser( $wp_customize, 'music_zone_pro_theme_options[team_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'music-zone-pro' ), $i ),
		'section'           => 'music_zone_pro_team_section',
		'choices'			=> music_zone_pro_post_choices(),
		'active_callback'	=> 'music_zone_pro_is_team_section_content_post_enable',
	) ) );

	$wp_customize->add_setting( 'music_zone_pro_theme_options[team_position_' . $i. ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'music_zone_pro_theme_options[team_position_' . $i. ']', array(
		'label'           	=> sprintf( esc_html__( 'Position Text %d', 'music-zone-pro' ), $i ),
		'section'        	=> 'music_zone_pro_team_section',
		'active_callback' 	=> 'music_zone_pro_is_team_section_enable',
		'type'				=> 'text',
	) );

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[team_position_' . $i. ']', array(
			'selector'            => '#music_zone_pro_team_section .section-content .entry-container .position_' . $i,
			'settings'            => 'music_zone_pro_theme_options[team_position_' . $i. ']',
		) );
	}


		
	$wp_customize->add_setting( 'music_zone_pro_theme_options[team_social_' . $i. ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new Music_Zone_Pro_Multi_Input_Custom_Control( $wp_customize, 'music_zone_pro_theme_options[team_social_' . $i. ']', array(
		'label'             => esc_html__( 'Social Link', 'music-zone-pro' ),
		'button_text'       => esc_html__( 'Add social', 'music-zone-pro' ),
		'section'           => 'music_zone_pro_team_section',
		'active_callback' 	=> 'music_zone_pro_is_team_section_enable',
	) ) );



    $wp_customize->add_setting( 'music_zone_pro_theme_options[team_hr_'. $i .']', array(
        'sanitize_callback' => 'sanitize_text_field'
    ) );

    $wp_customize->add_control( new Music_Zone_Pro_Customize_Horizontal_Line( $wp_customize, 'music_zone_pro_theme_options[team_hr_'. $i .']',
        array(
            'section'           => 'music_zone_pro_team_section',
            'active_callback'   => 'music_zone_pro_is_team_section_enable',
            'type'            => 'hr'
    ) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'music_zone_pro_theme_options[team_content_category]', array(
	'sanitize_callback' => 'music_zone_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Music_Zone_Pro_Dropdown_Taxonomies_Control( $wp_customize,'music_zone_pro_theme_options[team_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'music-zone-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'music-zone-pro' ),
	'section'           => 'music_zone_pro_team_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'music_zone_pro_is_team_section_content_category_enable'
) ) );