<?php
/**
 * Trending Product Section options
 *
 * @package Theme Palace
 * @subpackage Music Zone Pro Pro
 * @since Music Zone Pro Pro 1.0.0
 */
if ( !class_exists('WooCommerce') ) {
    return;
}
// Add trending_product section
$wp_customize->add_section( 'music_zone_pro_trending_product_section', array(
    'title'             => esc_html__( 'Trending Product','music-zone-pro' ),
    'description'       => esc_html__( 'Trending Product Section options.', 'music-zone-pro' ),
    'panel'             => 'music_zone_pro_front_page_panel',
    'active_callback'   => function( $control ) {
        return (
            music_zone_pro_is_fourth_layout( $control )
        );
    },
) );

// trending_product content enable control and setting
$wp_customize->add_setting( 'music_zone_pro_theme_options[trending_product_section_enable]', array(
    'default'           =>  $options['trending_product_section_enable'],
    'sanitize_callback' => 'music_zone_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Music_Zone_Pro_Switch_Control( $wp_customize, 'music_zone_pro_theme_options[trending_product_section_enable]', array(
    'label'             => esc_html__( 'Trending Product Section Enable', 'music-zone-pro' ),
    'section'           => 'music_zone_pro_trending_product_section',
    'on_off_label'      => music_zone_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'music_zone_pro_theme_options[trending_product_section_enable]', array(
        'selector'            => '#music_zone_pro_trending_product_section .tooltiptext',
        'settings'            => 'music_zone_pro_theme_options[trending_product_section_enable]',
    ) );
}

$wp_customize->add_setting( 'music_zone_pro_theme_options[trending_product_count]', array(
    'default'           => $options['trending_product_count'],
    'sanitize_callback' => 'music_zone_pro_sanitize_number_range',
    'validate_callback' => 'music_zone_pro_validate_trending_product_count',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[trending_product_count]', array(
    'label'             => esc_html__( 'Number of Product Per Column', 'music-zone-pro' ),
    'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'music-zone-pro' ),
    'section'           => 'music_zone_pro_trending_product_section',
    'active_callback'   => 'music_zone_pro_is_trending_product_section_enable',
    'type'              => 'number',
    'input_attrs'       => array(
        'min'   => 1,
        'max'   => 12,
        'style' => 'width: 100px;'
        ),
) );

for( $i = 1 ; $i <= 3 ; $i++ ){

$wp_customize->add_setting( 'music_zone_pro_theme_options[trending_product_column_'. $i .']', array(
        'sanitize_callback' => 'sanitize_text_field'
    ) );

$wp_customize->add_control( new Music_Zone_Pro_Customize_Column( $wp_customize, 'music_zone_pro_theme_options[trending_product_column_'. $i .']',
    array(
        'label'           => esc_html__('Column ', 'music-zone-pro').$i,
        'section'         => 'music_zone_pro_trending_product_section',
        'active_callback' => 'music_zone_pro_is_trending_product_section_enable',
        'type'            => 'column'
) ) );

// trending_product title setting and control
$wp_customize->add_setting( 'music_zone_pro_theme_options[trending_product_title_'.$i.']', array(
    'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[trending_product_title_'.$i.']', array(
    'label'             => esc_html__( 'Title', 'music-zone-pro' ),
    'section'           => 'music_zone_pro_trending_product_section',
    'active_callback'   => 'music_zone_pro_is_trending_product_section_enable',
    'type'              => 'text',
) );

$wp_customize->add_setting( 'music_zone_pro_theme_options[trending_content_type_'.$i.']', array(
    'default'           => 'product_cat',
    'sanitize_callback' => 'music_zone_pro_sanitize_select',
) );

$wp_customize->add_control( 'music_zone_pro_theme_options[trending_content_type_'.$i.']', array(
    'label'             => esc_html__( 'Content Type', 'music-zone-pro' ),
    'section'           => 'music_zone_pro_trending_product_section',
    'type'              => 'select',
    'active_callback'   => 'music_zone_pro_is_trending_product_section_enable',
    'choices'           => array(
                'product'           => esc_html__( 'Product', 'music-zone-pro' ),
                'product_cat'       => esc_html__( 'Product Category', 'music-zone-pro' ),
            )
) );

for ( $j=1 ; $j <= $options['trending_product_count'] ; $j++ ) { 
    $wp_customize->add_setting( 'music_zone_pro_theme_options[trending_product_content_page_'. $i.$j. ']', array(
        'sanitize_callback' => 'music_zone_pro_sanitize_page',
    ) );

    $wp_customize->add_control( new Music_Zone_Pro_Dropdown_Chooser( $wp_customize, 'music_zone_pro_theme_options[trending_product_content_page_' .$i.$j. ']', array(
            'label'             => sprintf( esc_html__( 'Select Product %d', 'music-zone-pro' ), $j ),
            'section'           => 'music_zone_pro_trending_product_section',
            'choices'           => music_zone_pro_product_choices(),
            'active_callback'   => 'music_zone_pro_is_trending_product_section_content_product_enable_'.$i,

    ) ) );
}

$wp_customize->add_setting(  'music_zone_pro_theme_options[trending_product_category_'.$i.']', array(
        'sanitize_callback' => 'absint',
    ) ) ;

$wp_customize->add_control( new Music_Zone_Pro_Dropdown_Taxonomies_Control( $wp_customize,'music_zone_pro_theme_options[trending_product_category_'.$i.']', array(
    'label'             => esc_html__( 'Select Product Categories', 'music-zone-pro' ),
    'section'           => 'music_zone_pro_trending_product_section',
    'taxonomy'          => 'product_cat',
    'type'              => 'dropdown-taxonomies',
    'active_callback'   => 'music_zone_pro_is_trending_product_section_content_category_enable_'.$i,
) ) );

$wp_customize->add_setting( 'music_zone_pro_theme_options[trending_product_hr_'. $i .']', array(
        'sanitize_callback' => 'sanitize_text_field'
    ) );

$wp_customize->add_control( new Music_Zone_Pro_Customize_Horizontal_Line( $wp_customize, 'music_zone_pro_theme_options[trending_product_hr_'. $i .']',
    array(
        'section'         => 'music_zone_pro_trending_product_section',
        'active_callback' => 'music_zone_pro_is_trending_product_section_enable',
        'type'            => 'hr'
) ) );

}