<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage  Music Zone Pro
 * @since  Music Zone Pro 1.0.0
 */


/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function music_zone_pro_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'music-zone-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    wp_reset_postdata();
    return  $choices;
}

/**
 * List of trips for post choices.
 * @return Array Array of post ids and name.
 */
function music_zone_pro_trip_choices() {
    $posts = get_posts( array( 'post_type' => 'itineraries', 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'music-zone-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of products for post choices.
 * @return Array Array of post ids and name.
 */
function music_zone_pro_product_choices() {
    $posts = get_posts( array( 'numberposts' => -1, 'post_type' => 'product' ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'music-zone-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of category for category choices.
 * @return Array Array of post ids and name.
 */
function music_zone_pro_category_choices() {
    $tax_args = array(
        'hierarchical' => 0,
        'taxonomy'     => 'category',
    );
    $taxonomies = get_categories( $tax_args );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'music-zone-pro' );
    foreach ( $taxonomies as $tax ) {
        $choices[ $tax->term_id ] = $tax->name;
    }
    return  $choices;
}

/**
 * List of category for category choices.
 * @return Array Array of post ids and name.
 */
function music_zone_pro_product_category_choices() {
    $tax_args = array(
        'hierarchical' => 0,
        'taxonomy'     => 'product_cat',
    );
    $taxonomies = get_categories( $tax_args );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'music-zone-pro' );
    foreach ( $taxonomies as $tax ) {
        $choices[ $tax->term_id ] = $tax->name;
    }
    return  $choices;
}

/**
 * List of audio for post choices.
 * @return Array Array of post ids and name.
 */
function music_zone_pro_audio_choices() {
    $posts = get_posts( array( 'numberposts' => -1, 'post_type' => 'attachment', 'post_mime_type' => 'audio' ) );
    $choices = array();
    $choices[0] = esc_html__( '--None--', 'music-zone-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}




if ( ! function_exists( 'music_zone_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function music_zone_pro_site_layout() {
        $music_zone_pro_site_layout = array(
            'wide'          => esc_url( get_template_directory_uri() . '/assets/images/full.png' ),
            'boxed-layout'  => esc_url( get_template_directory_uri() . '/assets/images/boxed.png' ),
            'frame-layout'  => esc_url( get_template_directory_uri() . '/assets/images/framed.png' ),
        );

        $output = apply_filters( 'music_zone_pro_site_layout', $music_zone_pro_site_layout );
        return $output;
    }
endif;

if ( ! function_exists( 'music_zone_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function music_zone_pro_selected_sidebar() {
        $music_zone_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'music-zone-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'music-zone-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'music-zone-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'music-zone-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'music-zone-pro' ),
        );

        $output = apply_filters( 'music_zone_pro_selected_sidebar', $music_zone_pro_selected_sidebar );

        return $output;
    }
endif;


if ( ! function_exists( 'music_zone_pro_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function music_zone_pro_global_sidebar_position() {
        $music_zone_pro_global_sidebar_position = array(
            'right-sidebar' => esc_url( get_template_directory_uri() . '/assets/images/right.png' ),
            'left-sidebar'  => esc_url( get_template_directory_uri() . '/assets/images/left.png' ),
            'no-sidebar'    => esc_url( get_template_directory_uri() . '/assets/images/full.png' ),
        );

        $output = apply_filters( 'music_zone_pro_global_sidebar_position', $music_zone_pro_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'music_zone_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function music_zone_pro_sidebar_position() {
        $music_zone_pro_sidebar_position = array(
            'right-sidebar'         => esc_url( get_template_directory_uri() . '/assets/images/right.png' ),
            'left-sidebar'          => esc_url( get_template_directory_uri() . '/assets/images/left.png' ),
            'no-sidebar'            => esc_url( get_template_directory_uri() . '/assets/images/full.png' ),
            'no-sidebar-content'    => esc_url( get_template_directory_uri() . '/assets/images/boxed.png' ),
        );

        $output = apply_filters( 'music_zone_pro_sidebar_position', $music_zone_pro_sidebar_position );

        return $output;
    }
endif;

if ( ! function_exists( 'music_zone_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function music_zone_pro_pagination_options() {
        $music_zone_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'music-zone-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'music-zone-pro' ),
            'infinite'  => esc_html__( 'Infinite', 'music-zone-pro' ),
        );

        $output = apply_filters( 'music_zone_pro_pagination_options', $music_zone_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'music_zone_pro_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function music_zone_pro_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'music-zone-pro' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'music-zone-pro' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'music-zone-pro' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'music-zone-pro' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'music-zone-pro' ),
            'spinner-dots'          => esc_html__( 'Dots', 'music-zone-pro' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'music-zone-pro' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'music-zone-pro' ),
        );
        return apply_filters( 'music_zone_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'music_zone_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function music_zone_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'music-zone-pro' ),
            'off'       => esc_html__( 'Disable', 'music-zone-pro' )
        );
        return apply_filters( 'music_zone_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'music_zone_pro_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function music_zone_pro_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'music-zone-pro' ),
            'off'       => esc_html__( 'No', 'music-zone-pro' )
        );
        return apply_filters( 'music_zone_pro_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'music_zone_pro_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function music_zone_pro_sortable_sections() {
        $options = music_zone_pro_get_theme_options();
        
        $sections = array(
            'slider'                => esc_html__( 'Slider', 'music-zone-pro' ),
            'service'               => esc_html__( 'Service', 'music-zone-pro' ),
            'playlist'              => esc_html__( 'Playlist', 'music-zone-pro' ),
            'album'                 => esc_html__( 'Album', 'music-zone-pro' ),
            'promotion'             => esc_html__( 'Promotion', 'music-zone-pro' ),
            'recent_product'        => esc_html__( 'Recent Product', 'music-zone-pro' ),
            'event'                 => esc_html__( 'Event', 'music-zone-pro' ),
            'gallery'               => esc_html__( 'Gallery', 'music-zone-pro' ),
            'about'                 => esc_html__( 'About', 'music-zone-pro' ),
            'team'                  => esc_html__( 'Team', 'music-zone-pro' ),
            'counter'               => esc_html__( 'Counter', 'music-zone-pro' ),
            'testimonial'           => esc_html__( 'Testimonial', 'music-zone-pro' ),
            'latest_posts'          => esc_html__( 'Latest Posts', 'music-zone-pro' ),
            'subscription'          => esc_html__( 'Subscription', 'music-zone-pro' ),
            'partners'              => esc_html__( 'Partners', 'music-zone-pro' ),
            'contact'               => esc_html__( 'Contact', 'music-zone-pro' ),
            'featured_posts'        => esc_html__( 'Featured Posts', 'music-zone-pro' ),
            'recent_posts'          => esc_html__( 'Recent Posts', 'music-zone-pro' ),
            'popular_posts'         => esc_html__( 'Popular Posts', 'music-zone-pro' ),
            'instagram'             => esc_html__( 'Instagram', 'music-zone-pro' ),
            'popular_products'      => esc_html__( 'Popular Products', 'music-zone-pro' ),
            'featured_products'     => esc_html__( 'Featured Products', 'music-zone-pro' ),
            'trending_product'      => esc_html__( 'Trending Products', 'music-zone-pro' ),


        );
      
        return apply_filters( 'music_zone_pro_sortable_sections', $sections );
    }
endif;


if ( ! function_exists( 'music_zone_pro_popular_product_content_type' ) ) :
    /**
     * Product Options
     * @return array site product options
     */
    function music_zone_pro_popular_product_content_type() {
        $music_zone_pro_popular_product_content_type = array(
            'category'  => esc_html__( 'Category', 'music-zone-pro' ),

        );

        if(class_exists('WooCommerce')){
            $music_zone_pro_popular_product_content_type = array_merge($music_zone_pro_popular_product_content_type, 
                array(
                    'product-category'   => esc_html__( 'Product Category', 'music-zone-pro' ),
                )
            );
        }

        $output = apply_filters( 'music_zone_pro_popular_product_content_type', $music_zone_pro_popular_product_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'music_zone_pro_typography_options' ) ) :
    function music_zone_pro_typography_options(){
    $font_family_arr = array();
    $font_family_arr[''] = esc_html__( '--Default--', 'music-zone-pro' );

    // Make the request
    $request = wp_remote_get( get_theme_file_uri( 'assets/webfonts.json' ) );

    if( is_wp_error( $request ) ) {
        return false; // Bail early
    }
     // Retrieve the data
    $body = wp_remote_retrieve_body( $request );
    $data = json_decode( $body );
    if ( ! empty( $data ) ) {
        foreach ( $data->items as $items => $fonts ) {
            $family_str_arr = explode( ' ', $fonts->family );
            $family_value = implode( '+', $family_str_arr );
            $font_family_arr[ $family_value ] = $fonts->family;
        }
    }

    return $font_family_arr;
}
endif;

if ( ! function_exists( 'music_zone_pro_album_content_type' ) ) :
    /**
     * Latest Release Options
     * @return array site recent_album options
     */
    function music_zone_pro_album_content_type() {
        $music_zone_pro_album_content_type = array(
            'page'      => esc_html__( 'Page', 'music-zone-pro' ),
            'post'      => esc_html__( 'Post', 'music-zone-pro' ),
            'category'  => esc_html__( 'Category', 'music-zone-pro' ),
        );

        if ( class_exists( 'WooCommerce' ) ) {
            $music_zone_pro_album_content_type = array_merge( $music_zone_pro_album_content_type, array(
                'product'   => esc_html__( 'Product', 'music-zone-pro' ),
                'product-category'   => esc_html__( 'Product Category', 'music-zone-pro' ),
                ) );
        }

        $output = apply_filters( 'music_zone_pro_album_content_type', $music_zone_pro_album_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'music_zone_pro_product_content_type' ) ) :
    /**
     * Product Options
     * @return array site product options
     */
    function music_zone_pro_product_content_type() {
        $music_zone_pro_product_content_type = array(
            'product'   => esc_html__( 'Product', 'music-zone-pro' ),
            'product-category'   => esc_html__( 'Product Category', 'music-zone-pro' ),
        );

        $output = apply_filters( 'music_zone_pro_product_content_type', $music_zone_pro_product_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'music_zone_pro_gallery_content_type' ) ) :
    /**
     * Gallery Options
     * @return array site gallery options
     */
    function music_zone_pro_gallery_content_type() {
        $music_zone_pro_gallery_content_type = array(
            'page'      => esc_html__( 'Page', 'music-zone-pro' ),
            'post'      => esc_html__( 'Post', 'music-zone-pro' ),
            'category'  => esc_html__( 'Category', 'music-zone-pro' ),
        );

        $output = apply_filters( 'music_zone_pro_gallery_content_type', $music_zone_pro_gallery_content_type );


        return $output;
    }
endif;

/**
 * List of events for post choices.
 * @return Array Array of post ids and name.
 */
function music_zone_pro_event_choices() {
    $posts = get_posts( array( 'numberposts' => -1, 'post_type' => 'tp-event' ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'music-zone-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}


/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function music_zone_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'music-zone-pro' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

if ( ! function_exists( 'music_zone_pro_event_content_type' ) ) :
    /**
     * Special Offer Options
     * @return array site event options
     */
    function music_zone_pro_event_content_type() {
        $music_zone_pro_event_content_type = array(
            'page'      => esc_html__( 'Page', 'music-zone-pro' ),
            'post'      => esc_html__( 'Post', 'music-zone-pro' ),
            'category'  => esc_html__( 'Category', 'music-zone-pro' ),
        );

        if ( class_exists( 'TP_Education' ) ) {
            $music_zone_pro_event_content_type = array_merge( $music_zone_pro_event_content_type, array(
                'event'   => esc_html__( 'Event', 'music-zone-pro' ),
                'event-category'   => esc_html__( 'Event Category', 'music-zone-pro' ),
                ) );
        }

        $output = apply_filters( 'music_zone_pro_event_content_type', $music_zone_pro_event_content_type );


        return $output;
    }
endif;