<?php
/**
 * Album Section
 *
 * This is the template for the content of album section
 *
 * @package Theme Palace
 * @subpackage Dark Music Pro
 * @since Dark Music Pro 1.0.0
 */
if ( ! function_exists( 'music_zone_pro_add_album_section' ) ) :
    /**
    * Add album section
    *
    *@since Dark Music Pro 1.0.0
    */
    function music_zone_pro_add_album_section() {
    	$options = music_zone_pro_get_theme_options();
        // Check if album is enabled on frontpage
        $album_enable = apply_filters( 'music_zone_pro_section_status', true, 'album_section_enable' );

        if ( true !== $album_enable ) {
            return false;
        }
        // Get album section details
        $section_details = array();
        $section_details = apply_filters( 'music_zone_pro_filter_album_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render album section now.
        music_zone_pro_render_album_section( $section_details );
    }
endif;

if ( ! function_exists( 'music_zone_pro_get_album_section_details' ) ) :
    /**
    * album section details.
    *
    * @since Dark Music Pro 1.0.0
    * @param array $input album section details.
    */
    function music_zone_pro_get_album_section_details( $input ) {
        $options = music_zone_pro_get_theme_options();

        // Content type.
        $album_content_type  = $options['album_content_type'];
        
        $content = array();
        switch ( $album_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= 3; $i++ ) {
                    if ( ! empty( $options['album_content_page_' . $i] ) ) {
                        $page_ids[] = $options['album_content_page_' . $i];
                        $post_subtitle[] = ! empty( $options['album_post_subtitle_' . $i] ) ? $options['album_post_subtitle_' . $i] : '';
                    }
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => 3,
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= 3; $i++ ) {
                    if ( ! empty( $options['album_content_post_' . $i] ) ) {
                        $post_ids[] = $options['album_content_post_' . $i];
                        $post_subtitle[] = ! empty( $options['album_post_subtitle_' . $i] ) ? $options['album_post_subtitle_' . $i] : '';
                    }
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => 3,
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['album_content_category'] ) ? $options['album_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => 3,
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'product':
                $page_ids = array();

                for ( $i = 1; $i <= 3; $i++ ) {
                    if ( ! empty( $options['album_content_product_' . $i] ) ) {
                        $page_ids[] = $options['album_content_product_' . $i];
                        $post_subtitle[] = ! empty( $options['album_post_subtitle_' . $i] ) ? $options['album_post_subtitle_' . $i] : '';
                    }
                }
                
                $args = array(
                    'post_type'         => 'product',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => 3,
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'product-category':
                $cat_id = ! empty( $options['album_content_product_category'] ) ? $options['album_content_product_category'] : '';
                $args = array(
                    'post_type'      => 'product',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'product_cat',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => 3,
                    );                    
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        $i = in_array( $album_content_type, array( 'category', 'product-category' ) ) ? 1 : 0;
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['excerpt']   = music_zone_pro_trim_content( 10 );
                $page_post['url']       = get_the_permalink();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';
               
                // Push to the main array.
                array_push( $content, $page_post );
                $i++;
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// album section content details.
add_filter( 'music_zone_pro_filter_album_section_details', 'music_zone_pro_get_album_section_details' );


if ( ! function_exists( 'music_zone_pro_render_album_section' ) ) :
  /**
   * Start album section
   *
   * @return string album content
   * @since Dark Music Pro 1.0.0
   *
   */
   function music_zone_pro_render_album_section( $content_details = array() ) {
        $options = music_zone_pro_get_theme_options();
        $album_content_type  = $options['album_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="music_zone_pro_album_section" class="album-section relative page-section same-background">
            <div class="wrapper">
                <?php if ( is_customize_preview()):
                    music_zone_pro_section_tooltip( 'album-section-class' );
                endif; ?>
                <div class="section-header">
                    <?php if ( !empty( $options['album_subtitle'] ) ): ?>
                        <p class="section-subtitle"><?php echo esc_html( $options['album_subtitle'] ); ?></p>
                    <?php endif ?>
                    <?php if ( !empty( $options['album_title'] ) ): ?>
                        <h2 class="section-title"><?php echo esc_html( $options['album_title'] ); ?></h2>
                    <?php endif ?>                    
                </div><!-- .section-header -->

                <div class="section-content col-3 clear">
                    <?php $i=1; foreach ( $content_details as $content ) : ?>
                    <article>
                        <div class="album-item">
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                <a href="<?php echo esc_url( $content['url'] ); ?>"></a>
                            </div><!-- .featured-image -->

                            <div class="entry-container">
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>

                                <?php if ( !empty($options['album_post_subtitle_'.$i]) ): ?>
                                    <div class="entry-content">
                                        <p><?php echo esc_html( $options['album_post_subtitle_'.$i] ); ?></p>
                                    </div><!-- .entry-content -->
                                <?php endif ?>                            
                            </div><!-- .entry-container -->
                        </div><!-- .album-item -->
                    </article>
                    <?php $i++; endforeach; ?>
                </div><!-- .col-3 -->
            </div><!-- .wrapper -->
        </div><!-- #music_zone_pro_album_section -->    
        
    <?php }
endif;