<?php
/**
 * Event section
 *
 * This is the template for the content of event section
 *
 * @package Theme Palace
 * @subpackage Music Zone Pro
 * @since Music Zone Pro 1.0.0
 */
if ( ! function_exists( 'music_zone_pro_add_event_section' ) ) :
    /**
    * Add event section
    *
    *@since Music Zone Pro 1.0.0
    */
    function music_zone_pro_add_event_section() {
    	$options = music_zone_pro_get_theme_options();
        // Check if event is enabled on frontpage
        $event_enable = apply_filters( 'music_zone_pro_section_status', true, 'event_section_enable' );

        if ( true !== $event_enable ) {
            return false;
        }
        // Get event section details
        $section_details = array();
        $section_details = apply_filters( 'music_zone_pro_filter_event_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render event section now.
        music_zone_pro_render_event_section( $section_details );
    }
endif;

if ( ! function_exists( 'music_zone_pro_get_event_section_details' ) ) :
    /**
    * event section details.
    *
    * @since Music Zone Pro 1.0.0
    * @param array $input event section details.
    */
    function music_zone_pro_get_event_section_details( $input ) {
        $options = music_zone_pro_get_theme_options();

        // Content type.
        $event_content_type  = $options['event_content_type'];
        $event_count = ! empty( $options['event_count'] ) ? $options['event_count'] : 3;

        $content = array();
        switch ( $event_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $event_count; $i++ ) {
                    if ( ! empty( $options['event_content_page_' . $i] ) )
                        $page_ids[] = $options['event_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $event_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $event_count; $i++ ) {
                    if ( ! empty( $options['event_content_post_' . $i] ) )
                        $post_ids[] = $options['event_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $event_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['event_content_category'] ) ? $options['event_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $event_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'event':
                $page_ids = array();

                for ( $i = 1; $i <= $event_count; $i++ ) {
                    if ( ! empty( $options['event_content_event_' . $i] ) )
                        $page_ids[] = $options['event_content_event_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'tp-event',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $event_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'event-category':
                $cat_id = ! empty( $options['event_content_event_category'] ) ? $options['event_content_event_category'] : '';
                $args = array(
                    'post_type'      => 'tp-event',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'tp-event-category',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $event_count ),
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = music_zone_pro_trim_content( 5 );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-150x150.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// event section content details.
add_filter( 'music_zone_pro_filter_event_section_details', 'music_zone_pro_get_event_section_details' );


if ( ! function_exists( 'music_zone_pro_render_event_section' ) ) :
  /**
   * Start event section
   *
   * @return string event content
   * @since Music Zone Pro 1.0.0
   *
   */
   function music_zone_pro_render_event_section( $content_details = array() ) {
        $options = music_zone_pro_get_theme_options();
        $event_content_type  = $options['event_content_type'];
        $readmore = ! empty( $options['event_readmore'] ) ? $options['event_readmore'] : esc_html__( 'Buy Ticket', 'music-zone-pro' );
        $bg_image = !empty( $options['event_bg_image'] ) ? $options['event_bg_image'] : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>
            <div id="music_zone_pro_events_section" class="event-section relative page-section" style="background-image: url('<?php echo esc_url( $bg_image ) ?>');">
                <div class="overlay"></div>
                <div class="wrapper">
                    <?php if ( is_customize_preview()):
                    music_zone_pro_section_tooltip( 'events-section-class' );
                    endif; ?>
                    <div class="section-header">
                        <?php if ( !empty( $options['event_subtitle'] ) ): ?>
                            <p class="section-subtitle"><?php echo esc_html( $options['event_subtitle'] ); ?></p>
                        <?php endif ?>
                        <?php if ( !empty( $options['event_title'] ) ): ?>
                            <h2 class="section-title"><?php echo esc_html( $options['event_title'] ); ?></h2>
                        <?php endif ?>
                        
                    </div><!-- .section-header -->

                    <div class="section-content col-2 clear">
                        <?php $i=1; foreach ( $content_details as $content ) : 
                            if ( in_array( $event_content_type, array( 'event', 'event-category' ) ) && class_exists( 'TP_Education' ) ) :
                                $event_date = get_tp_event_date( $content['id'] );
                                $event_location = get_post_meta( $content['id'], 'tp_event_location_value', true );
                                $event_time = get_tp_event_start_time( $content['id'] );
                            endif;
                            ?>
                            <article>
                                <div class="event-item clear">
                                    <?php if ( in_array( $event_content_type, array( 'event', 'event-category' ) ) && ! empty( $event_date ) ) : ?>
                                        <?php
                                        $date     = get_post_meta( $content['id'], 'tp_event_date_value', true );
                                        // Break a string i.e $date into an array
                                        $arr_date = explode( ' ', $date );
                                        $day      = $arr_date[1];
                                        $day      = str_replace( ',', "", $day );
                                        $month    = $arr_date[0];
                                        $month    = substr( $month , 0, 3 );      
                                        ?>
                                         <span class="posted-on">
                                            <a href="<?php echo esc_url( $content['url'] ); ?>" rel="bookmark">
                                                <time class="entry-date published updated" datetime="2018-04-06T11:33:16+00:00"><span><?php echo $day; ?></span><?php echo esc_html( $month ); ?></time>
                                            </a>
                                        </span><!-- .posted-on -->
                                        <?php else : ?>
                                         <span class="posted-on">
                                            <a href="<?php echo esc_url( $content['url'] ); ?>" rel="bookmark">
                                                <time class="entry-date published updated" datetime="2018-04-06T11:33:16+00:00"><span><?php echo get_the_date( 'j', $content['id'] ); ?></span><?php echo esc_html( get_the_date( 'M', $content['id'] ) ); ?></time>
                                            </a>
                                        </span><!-- .posted-on -->
                                    <?php endif; ?>

                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                        <?php if ( in_array( $event_content_type, array( 'event', 'event-category' ) ) && ! empty( $event_location ) ) : ?>
                                            <p class="event-location"><?php echo esc_html( $event_location ); ?></p>
                                            <?php else : ?>
                                               <?php if ( !empty($options['event_location_'.$i]) ): ?>
                                                <p class="location"><?php echo esc_html( $options['event_location_'.$i] ); ?></p>
                                            <?php endif ?>
                                        <?php endif; ?>
                                    </header>
                                    <div class="buy-ticket">
                                        <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $readmore ); ?></a>
                                    </div><!-- .buy-ticket -->
                                </div><!-- .event-item -->
                            </article>
                        <?php $i++; endforeach; ?>
                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- #music_zone_pro_events_section -->
       
    <?php }
endif;