<?php
/**
 * Partners section
 *
 * This is the template for the content of partners section
 *
 * @package Theme Palace
 * @subpackage Music Zone Pro
 * @since Music Zone Pro 1.0.0
 */
if ( ! function_exists( 'music_zone_pro_add_partners_section' ) ) :
    /**
    * Add partners section
    *
    *@since Music Zone Pro 1.0.0
    */
    function music_zone_pro_add_partners_section() {
        $options = music_zone_pro_get_theme_options();
        // Check if partners is enabled on frontpage
        $partners_enable = apply_filters( 'music_zone_pro_section_status', true, 'partners_section_enable' );

        if ( true !== $partners_enable ) {
            return false;
        }

        // Render partners section now.
        music_zone_pro_render_partners_section();
    }
endif;

if ( ! function_exists( 'music_zone_pro_render_partners_section' ) ) :
  /**
   * Start partners section
   *
   * @return string partners content
   * @since Music Zone Pro 1.0.0
   *
   */
   function music_zone_pro_render_partners_section() {
        $options = music_zone_pro_get_theme_options();
      
        ?>

        <div id="music_zone_pro_partners_section" class="relative page-section">
          <div class="wrapper">
            <div class="section-header">
              <?php if( !empty( $options['partners_subtitle'] ) ): ?>
                <p class="section-subtitle"><?php echo esc_html( $options['partners_subtitle'] ); ?></p>
              <?php endif;
              if( !empty( $options['partners_title'] ) ):
                ?>
              <h2 class="section-title"><?php echo esc_html( $options['partners_title'] ); ?></h2>
            <?php endif; ?>
          </div><!-- .section-header -->

          <div class="col-4">

            <?php for ( $i = 1; $i <= $options['partners_count']; $i++){ ?>

            <article>
              <?php if( !empty( $options['partners_url_' . $i] ) && !empty( $options['partners_image_' . $i] ) ): ?>
                <div class="client-logo"><a href="<?php echo esc_url( $options['partners_url_' . $i] ); ?>" target="_blank"><img src="<?php echo esc_url( $options['partners_image_' . $i] ); ?>" alt="08"></a></div>
              <?php endif; ?>
            </article>

            <?php } ?>

          </div><!-- .col-4 -->
        </div><!-- .wrapper -->
      </div><!-- #music_zone_pro_partners_section -->
            
    <?php }
endif;