<?php
/**
 * Promotion section
 *
 * This is the template for the content of promotion section
 *
 * @package Theme Palace
 * @subpackage Music Zone Pro
 * @since Music Zone Pro 1.0.0
 */
if ( ! function_exists( 'music_zone_pro_add_promotion_section' ) ) :
    /**
    * Add promotion section
    *
    *@since Music Zone Pro 1.0.0
    */
    function music_zone_pro_add_promotion_section() {
        $options = music_zone_pro_get_theme_options();
        // Check if promotion is enabled on frontpage
        $promotion_enable = apply_filters( 'music_zone_pro_section_status', true, 'promotion_section_enable' );

        if ( true !== $promotion_enable ) {
            return false;
        }
        // Get promotion section details
        $section_details = array();
        $section_details = apply_filters( 'music_zone_pro_filter_promotion_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render promotion section now.
        music_zone_pro_render_promotion_section( $section_details );
    }
endif;

if ( ! function_exists( 'music_zone_pro_get_promotion_section_details' ) ) :
    /**
    * promotion section details.
    *
    * @since Music Zone Pro 1.0.0
    * @param array $input promotion section details.
    */
    function music_zone_pro_get_promotion_section_details( $input ) {
        $options = music_zone_pro_get_theme_options();

        // Content type.
        $promotion_content_type  = $options['promotion_content_type'];
        
        $content = array();
        switch ( $promotion_content_type ) {
            
            case 'custom':
                $custom['title']        = ! empty( $options['promotion_title'] ) ? $options['promotion_title'] : '';
                $custom['excerpt']      = ! empty( $options['promotion_description'] ) ? $options['promotion_description'] : '';
                $custom['image']        = ! empty( $options['promotion_image'] ) ? $options['promotion_image'] : get_template_directory_uri() . '/assets/uploads/call-to-action.jpg';
                $custom['url']          = ! empty( $options['promotion_btn_link'] ) ? $options['promotion_btn_link'] : '';

                // Push to the main array.
                array_push( $content, $custom );
            break;

            case 'page':
                $page_id = ! empty( $options['promotion_content_page'] ) ? $options['promotion_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['promotion_content_post'] ) ? $options['promotion_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            default:
            break;
        }

        if ( 'custom' !== $promotion_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = music_zone_pro_trim_content( 25 );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/call-to-action.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        endif;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// promotion section content details.
add_filter( 'music_zone_pro_filter_promotion_section_details', 'music_zone_pro_get_promotion_section_details' );


if ( ! function_exists( 'music_zone_pro_render_promotion_section' ) ) :
  /**
   * Start promotion section
   *
   * @return string promotion content
   * @since Music Zone Pro 1.0.0
   *
   */
   function music_zone_pro_render_promotion_section( $content_details = array() ) {
    $options = music_zone_pro_get_theme_options();
    $readmore = ! empty( $options['promotion_btn_title'] ) ? $options['promotion_btn_title'] : esc_html__( 'Read More', 'music-zone-pro' );

    if ( empty( $content_details ) ) {
        return;
    } 

    foreach ( $content_details as $content ) : ?>
        <div id="music_zone_pro_promotion_section" class="promotion-section relative page-section" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
            <div class="overlay"></div>
            <div class="wrapper">
                <?php if ( is_customize_preview()):
                    music_zone_pro_section_tooltip( 'promotion-section-class' );
                endif; ?>
                <header class="entry-header">
                    <h2 class="entry-title"><?php echo esc_html( $content['title'] ); ?></h2>
                </header>

                <div class="entry-content">
                    <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                </div><!-- .entry-content -->

                <?php
                if ( $options['home_layout'] == 'default-design' && !empty( $options['promotion_btn_title'] ) ) {
                    ?>
                    <div class="read-more">
                        <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $readmore ); ?></a>
                    </div><!-- .read-more -->
                    <?php

                } elseif (  $options['home_layout'] == 'second-design' && !empty( $options['promotion_video_btn_url']  ) || $options['home_layout'] == 'third-design' && !empty( $options['promotion_video_btn_url']  ) || $options['home_layout'] == 'fourth-design' && !empty( $options['promotion_video_btn_url']  ) ) {
                    ?>
                    <div class="video-button">
                        <a href="<?php echo esc_url( $options['promotion_video_btn_url'] ); ?>" class="popup-video">
                            <svg viewBox="0 0 373.008 373.008" class="icon-media-play">
                                <path d="M61.792,2.588C64.771,0.864,68.105,0,71.444,0c3.33,0,6.663,0.864,9.655,2.588l230.116,167.2
                                c5.963,3.445,9.656,9.823,9.656,16.719c0,6.895-3.683,13.272-9.656,16.713L81.099,370.427c-5.972,3.441-13.334,3.441-19.302,0
                                c-5.973-3.453-9.66-9.833-9.66-16.724V19.305C52.137,12.413,55.818,6.036,61.792,2.588z"/>
                            </svg>
                        </a>
                    </div><!-- .video-button -->
                    <?php
                }
                ?>
            </div><!-- .wrapper -->
        </div><!-- #music_zone_pro_promotion_section -->
    <?php endforeach; 
    }
endif;
